<?php
/**
 * Agent Reply Ticket
 *
 * @package     AutomatorWP\Integrations\Awesome_Support\Triggers\Agent_Reply_Ticket
 * @author      AutomatorWP <contact@automatorwp.com>, Ruben Garcia <rubengcdev@gmail.com>
 * @since       1.0.0
 */
// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

class AutomatorWP_Awesome_Support_Agent_Reply_Ticket extends AutomatorWP_Integration_Trigger {

    public $integration = 'awesome_support';
    public $trigger = 'awesome_support_agent_reply_ticket';

    /**
     * Register the trigger
     *
     * @since 1.0.0
     */
    public function register() {

        automatorwp_register_trigger( $this->trigger, array(
            'integration'       => $this->integration,
            'label'             => __( 'Agent replies to a ticket', 'automatorwp-awesome-support' ),
            'select_option'     => __( 'Agent <strong>replies</strong> to a ticket', 'automatorwp-awesome-support' ),
            /* translators: %1$s: Number of times. */
            'edit_label'        => sprintf( __( 'Agent replies to a ticket %1$s time(s)', 'automatorwp-awesome-support' ), '{times}' ),
            'log_label'         => __( 'Agent replies to a ticket', 'automatorwp-awesome-support' ),
            'action'            => 'wpas_add_reply_complete',
            'function'          => array( $this, 'listener' ),
            'priority'          => 10,
            'accepted_args'     => 2,
            'options'           => array(
                'times' => automatorwp_utilities_times_option()
            ),
            'tags' => array(
                automatorwp_utilities_post_tags( __( 'Ticket', 'automatorwp-awesome-support' ) ),
                'times' => automatorwp_utilities_times_tag( true )
            )
        ) );

    }

    /**
     * Trigger listener
     *
     * @since 1.0.0
     *
     * @param int   $reply_id   Reply ID
     * @param array $data       Data to be inserted as the reply
     */
    public function listener( $reply_id, $data ) {

        $user_id = absint( $data['post_author'] );

        // Bail if user is not an agent
        if( ! user_can( $user_id, 'edit_ticket' ) ) {
            return;
        }

        $ticket_id = absint( $data['post_parent'] );

        automatorwp_trigger_event( array(
            'trigger' => $this->trigger,
            'post_id' => $ticket_id,
            'user_id' => $user_id,
        ) );

    }

}

new AutomatorWP_Awesome_Support_Agent_Reply_Ticket();