<?php
/**
 * Plugin Name:           AutomatorWP - Block Users
 * Plugin URI:            https://automatorwp.com/add-ons/block-users/
 * Description:           Block users and roles for being able to complete any automation.
 * Version:               1.0.1
 * Author:                AutomatorWP
 * Author URI:            https://automatorwp.com/
 * Text Domain:           automatorwp-block-users
 * Domain Path:           /languages/
 * Requires at least:     4.4
 * Tested up to:          5.5
 * License:               GNU AGPL v3.0 (http://www.gnu.org/licenses/agpl.txt)
 *
 * @package               AutomatorWP\Block_Users
 * @author                AutomatorWP
 * @copyright             Copyright (c) AutomatorWP
 */

final class AutomatorWP_Block_Users {

    /**
     * @var         AutomatorWP_Block_Users $instance The one true AutomatorWP_Block_Users
     * @since       1.0.0
     */
    private static $instance;

    /**
     * Get active instance
     *
     * @access      public
     * @since       1.0.0
     * @return      AutomatorWP_Block_Users self::$instance The one true AutomatorWP_Block_Users
     */
    public static function instance() {
        if( !self::$instance ) {
            self::$instance = new AutomatorWP_Block_Users();
            self::$instance->constants();
            self::$instance->includes();
            self::$instance->hooks();
            self::$instance->load_textdomain();
        }

        return self::$instance;
    }

    /**
     * Setup plugin constants
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function constants() {
        // Plugin version
        define( 'AUTOMATORWP_BLOCK_USERS_VER', '1.0.1' );

        // Plugin file
        define( 'AUTOMATORWP_BLOCK_USERS_FILE', __FILE__ );

        // Plugin path
        define( 'AUTOMATORWP_BLOCK_USERS_DIR', plugin_dir_path( __FILE__ ) );

        // Plugin URL
        define( 'AUTOMATORWP_BLOCK_USERS_URL', plugin_dir_url( __FILE__ ) );
    }

    /**
     * Include plugin files
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function includes() {

        if( $this->meets_requirements() ) {

            // Includes
            require_once AUTOMATORWP_BLOCK_USERS_DIR . 'includes/admin.php';
            require_once AUTOMATORWP_BLOCK_USERS_DIR . 'includes/filters.php';

        }
    }

    /**
     * Setup plugin hooks
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function hooks() {

        add_filter( 'automatorwp_licenses_meta_boxes', array( $this, 'license' ) );

        // Setup our activation and deactivation hooks
        register_activation_hook( __FILE__, array( $this, 'activate' ) );
        register_deactivation_hook( __FILE__, array( $this, 'deactivate' ) );

        add_action( 'admin_notices', array( $this, 'admin_notices' ) );
    }

    /**
     * Licensing
     *
     * @since 1.0.0
     *
     * @param array $meta_boxes
     *
     * @return array
     */
    function license( $meta_boxes ) {

        $meta_boxes['automatorwp-block-users-license'] = array(
            'title' => 'Block Users',
            'fields' => array(
                'automatorwp_block_users_license' => array(
                    'type' => 'edd_license',
                    'file' => AUTOMATORWP_BLOCK_USERS_FILE,
                    'item_name' => 'Block Users',
                ),
            )
        );

        return $meta_boxes;

    }

    /**
     * Activation hook for the plugin.
     *
     * @since  1.0.0
     */
    function activate() {

        if( $this->meets_requirements() ) {

        }

    }

    /**
     * Deactivation hook for the plugin.
     *
     * @since  1.0.0
     */
    function deactivate() {

    }

    /**
     * Plugin admin notices.
     *
     * @since  1.0.0
     */
    public function admin_notices() {

        if ( ! $this->meets_requirements() && ! defined( 'AUTOMATORWP_ADMIN_NOTICES' ) ) : ?>

            <div id="message" class="notice notice-error is-dismissible">
                <p>
                    <?php printf(
                        __( 'AutomatorWP - Block Users requires %s in order to work. Please install and activate them.', 'automatorwp-block-users' ),
                        '<a href="https://wordpress.org/plugins/automatorwp/" target="_blank">AutomatorWP</a>'
                    ); ?>
                </p>
            </div>

            <?php define( 'AUTOMATORWP_ADMIN_NOTICES', true ); ?>

        <?php endif;

    }

    /**
     * Check if there are all plugin requirements
     *
     * @since  1.0.0
     *
     * @return bool True if installation meets all requirements
     */
    private function meets_requirements() {

        if ( ! class_exists( 'AutomatorWP' ) ) {
            return false;
        }

        return true;

    }

    /**
     * Internationalization
     *
     * @access      public
     * @since       1.0.0
     * @return      void
     */
    public function load_textdomain() {

        // Set filter for language directory
        $lang_dir = AUTOMATORWP_BLOCK_USERS_DIR . '/languages/';
        $lang_dir = apply_filters( 'automatorwp_block_users_languages_directory', $lang_dir );

        // Traditional WordPress plugin locale filter
        $locale = apply_filters( 'plugin_locale', get_locale(), 'automatorwp-block-users' );
        $mofile = sprintf( '%1$s-%2$s.mo', 'automatorwp-block-users', $locale );

        // Setup paths to current locale file
        $mofile_local   = $lang_dir . $mofile;
        $mofile_global  = WP_LANG_DIR . '/automatorwp-block-users/' . $mofile;

        if( file_exists( $mofile_global ) ) {
            // Look in global /wp-content/languages/automatorwp-block-users/ folder
            load_textdomain( 'automatorwp-block-users', $mofile_global );
        } elseif( file_exists( $mofile_local ) ) {
            // Look in local /wp-content/plugins/automatorwp-block-users/languages/ folder
            load_textdomain( 'automatorwp-block-users', $mofile_local );
        } else {
            // Load the default language files
            load_plugin_textdomain( 'automatorwp-block-users', false, $lang_dir );
        }

    }

}

/**
 * The main function responsible for returning the one true AutomatorWP_Block_Users instance to functions everywhere
 *
 * @since       1.0.0
 * @return      \AutomatorWP_Block_Users The one true AutomatorWP_Block_Users
 */
function AutomatorWP_Block_Users() {
    return AutomatorWP_Block_Users::instance();
}
add_action( 'plugins_loaded', 'AutomatorWP_Block_Users' );
