<?php
/**
 * Plugin Name:           AutomatorWP - Digimember
 * Plugin URI:            https://automatorwp.com/add-ons/digimember/
 * Description:           Connect AutomatorWP with Digimember.
 * Version:               1.0.0
 * Author:                AutomatorWP
 * Author URI:            https://automatorwp.com/
 * Text Domain:           automatorwp-digimember
 * Domain Path:           /languages/
 * Requires at least:     4.4
 * Tested up to:          5.4
 * License:               GNU AGPL v3.0 (http://www.gnu.org/licenses/agpl.txt)
 *
 * @package               AutomatorWP\Digimember
 * @author                AutomatorWP
 * @copyright             Copyright (c) AutomatorWP
 */

final class AutomatorWP_Digimember {

    /**
     * @var         AutomatorWP_Digimember $instance The one true AutomatorWP_Digimember
     * @since       1.0.0
     */
    private static $instance;

    /**
     * Get active instance
     *
     * @access      public
     * @since       1.0.0
     * @return      AutomatorWP_Digimember self::$instance The one true AutomatorWP_Digimember
     */
    public static function instance() {
        if( !self::$instance ) {
            self::$instance = new AutomatorWP_Digimember();
            self::$instance->constants();
            self::$instance->includes();
            self::$instance->hooks();
            self::$instance->load_textdomain();
        }

        return self::$instance;
    }

    /**
     * Setup plugin constants
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function constants() {
        // Plugin version
        define( 'AUTOMATORWP_DIGIMEMBER_VER', '1.0.0' );

        // Plugin file
        define( 'AUTOMATORWP_DIGIMEMBER_FILE', __FILE__ );

        // Plugin path
        define( 'AUTOMATORWP_DIGIMEMBER_DIR', plugin_dir_path( __FILE__ ) );

        // Plugin URL
        define( 'AUTOMATORWP_DIGIMEMBER_URL', plugin_dir_url( __FILE__ ) );
    }

    /**
     * Include plugin files
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function includes() {

        if( $this->meets_requirements() ) {

            // Triggers
            require_once AUTOMATORWP_DIGIMEMBER_DIR . 'includes/triggers/purchase-product.php';
            require_once AUTOMATORWP_DIGIMEMBER_DIR . 'includes/triggers/purchase-membership-product.php';
            require_once AUTOMATORWP_DIGIMEMBER_DIR . 'includes/triggers/purchase-download-product.php';
            require_once AUTOMATORWP_DIGIMEMBER_DIR . 'includes/triggers/cancel-product.php';
            require_once AUTOMATORWP_DIGIMEMBER_DIR . 'includes/triggers/cancel-membership-product.php';
            require_once AUTOMATORWP_DIGIMEMBER_DIR . 'includes/triggers/cancel-download-product.php';

            // Includes
            require_once AUTOMATORWP_DIGIMEMBER_DIR . 'includes/ajax-functions.php';
            require_once AUTOMATORWP_DIGIMEMBER_DIR . 'includes/functions.php';

        }
    }

    /**
     * Setup plugin hooks
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function hooks() {

        add_action( 'automatorwp_init', array( $this, 'register_integration' ) );

        add_filter( 'automatorwp_licenses_meta_boxes', array( $this, 'license' ) );

        // Setup our activation and deactivation hooks
        register_activation_hook( __FILE__, array( $this, 'activate' ) );
        register_deactivation_hook( __FILE__, array( $this, 'deactivate' ) );

        add_action( 'admin_notices', array( $this, 'admin_notices' ) );
    }

    /**
     * Registers this integration
     *
     * @since 1.0.0
     */
    function register_integration() {

        automatorwp_register_integration( 'digimember', array(
            'label' => 'Digimember',
            'icon'  => AUTOMATORWP_DIGIMEMBER_URL . '/assets/digimember.svg',
        ) );

    }

    /**
     * Licensing
     *
     * @since 1.0.0
     *
     * @param array $meta_boxes
     *
     * @return array
     */
    function license( $meta_boxes ) {

        $meta_boxes['automatorwp-digimember-license'] = array(
            'title' => 'Digimember',
            'fields' => array(
                'automatorwp_digimember_license' => array(
                    'type' => 'edd_license',
                    'file' => AUTOMATORWP_DIGIMEMBER_FILE,
                    'item_name' => 'Digimember',
                ),
            )
        );

        return $meta_boxes;

    }

    /**
     * Activation hook for the plugin.
     *
     * @since  1.0.0
     */
    function activate() {

        if( $this->meets_requirements() ) {

        }

    }

    /**
     * Deactivation hook for the plugin.
     *
     * @since  1.0.0
     */
    function deactivate() {

    }

    /**
     * Plugin admin notices.
     *
     * @since  1.0.0
     */
    public function admin_notices() {

        if ( ! $this->meets_requirements() && ! defined( 'AUTOMATORWP_ADMIN_NOTICES' ) ) : ?>

            <div id="message" class="notice notice-error is-dismissible">
                <p>
                    <?php printf(
                        __( 'AutomatorWP - Digimember requires %s and %s in order to work. Please install and activate them.', 'automatorwp-digimember' ),
                        '<a href="https://wordpress.org/plugins/automatorwp/" target="_blank">AutomatorWP</a>',
                        '<a href="https://digimember.com/" target="_blank">Digimember</a>'
                    ); ?>
                </p>
            </div>

            <?php define( 'AUTOMATORWP_ADMIN_NOTICES', true ); ?>

        <?php endif;

    }

    /**
     * Check if there are all plugin requirements
     *
     * @since  1.0.0
     *
     * @return bool True if installation meets all requirements
     */
    private function meets_requirements() {

        if ( ! class_exists( 'AutomatorWP' ) ) {
            return false;
        }

        if ( ! function_exists( 'digimember_init' ) ) {
            return false;
        }

        return true;

    }

    /**
     * Internationalization
     *
     * @access      public
     * @since       1.0.0
     * @return      void
     */
    public function load_textdomain() {

        // Set filter for language directory
        $lang_dir = AUTOMATORWP_DIGIMEMBER_DIR . '/languages/';
        $lang_dir = apply_filters( 'automatorwp_digimember_languages_directory', $lang_dir );

        // Traditional WordPress plugin locale filter
        $locale = apply_filters( 'plugin_locale', get_locale(), 'automatorwp-digimember' );
        $mofile = sprintf( '%1$s-%2$s.mo', 'automatorwp-digimember', $locale );

        // Setup paths to current locale file
        $mofile_local   = $lang_dir . $mofile;
        $mofile_global  = WP_LANG_DIR . '/automatorwp-digimember/' . $mofile;

        if( file_exists( $mofile_global ) ) {
            // Look in global /wp-content/languages/automatorwp-digimember/ folder
            load_textdomain( 'automatorwp-digimember', $mofile_global );
        } elseif( file_exists( $mofile_local ) ) {
            // Look in local /wp-content/plugins/automatorwp-digimember/languages/ folder
            load_textdomain( 'automatorwp-digimember', $mofile_local );
        } else {
            // Load the default language files
            load_plugin_textdomain( 'automatorwp-digimember', false, $lang_dir );
        }

    }

}

/**
 * The main function responsible for returning the one true AutomatorWP_Digimember instance to functions everywhere
 *
 * @since       1.0.0
 * @return      \AutomatorWP_Digimember The one true AutomatorWP_Digimember
 */
function AutomatorWP_Digimember() {
    return AutomatorWP_Digimember::instance();
}
add_action( 'plugins_loaded', 'AutomatorWP_Digimember' );
