<?php
/**
 * Agent Close Ticket
 *
 * @package     AutomatorWP\Integrations\Fluent_Support\Triggers\Agent_Close_Ticket
 * @author      AutomatorWP <contact@automatorwp.com>, Ruben Garcia <rubengcdev@gmail.com>
 * @since       1.0.0
 */
// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

class AutomatorWP_Fluent_Support_Agent_Close_Ticket extends AutomatorWP_Integration_Trigger {

    public $integration = 'fluent_support';
    public $trigger = 'fluent_support_agent_close_ticket';

    /**
     * Register the trigger
     *
     * @since 1.0.0
     */
    public function register() {

        automatorwp_register_trigger( $this->trigger, array(
            'integration'       => $this->integration,
            'label'             => __( 'Agent closes a ticket', 'automatorwp-fluent-support' ),
            'select_option'     => __( 'Agent <strong>closes</strong> a ticket', 'automatorwp-fluent-support' ),
            /* translators: %1$s: Number of times. */
            'edit_label'        => sprintf( __( 'Agent closes a ticket %1$s time(s)', 'automatorwp-fluent-support' ), '{times}' ),
            'log_label'         => __( 'Agent closes a ticket', 'automatorwp-fluent-support' ),
            'action'            => 'fluent_support/ticket_closed',
            'function'          => array( $this, 'listener' ),
            'priority'          => 10,
            'accepted_args'     => 3,
            'options'           => array(
                'times' => automatorwp_utilities_times_option()
            ),
            'tags' => array(
                automatorwp_utilities_post_tags( __( 'Ticket', 'automatorwp-fluent-support' ) ),
                'times' => automatorwp_utilities_times_tag( true )
            )
        ) );

    }

    /**
     * Trigger listener
     *
     * @since 1.0.0
     *
     * @param array $ticket Ticket data
     */
    public function listener( $ticket ) {

        global $wpdb;
        
        $agent_id = absint( $ticket['agent_id'] );
        $ticket_id = absint( $ticket['id'] );

        // Bail if agent not assigned
        if( $agent_id === 0 ) {
            return;
        }

        $agent = $wpdb->get_row( "SELECT * FROM {$wpdb->prefix}fs_persons WHERE id={$agent_id}");

        // Bail if agent not found
        if( ! $agent ) {
            return;
        }

        $user_id = absint( $agent->user_id );

        // If not user ID assigned, try to find the user by email
        if( $user_id === 0 ) {
            $user = get_user_by( 'email', $agent->email );

            // Bail if user not found
            if( ! $user ) {
                return;
            }

            $user_id = $user->ID;
        }

        automatorwp_trigger_event( array(
            'trigger' => $this->trigger,
            'post_id' => $ticket_id,
            'user_id' => $user_id,
        ) );

    }

}

new AutomatorWP_Fluent_Support_Agent_Close_Ticket();