<?php
/**
 * Client Reply Ticket
 *
 * @package     AutomatorWP\Integrations\Fluent_Support\Triggers\Client_Reply_Ticket
 * @author      AutomatorWP <contact@automatorwp.com>, Ruben Garcia <rubengcdev@gmail.com>
 * @since       1.0.0
 */
// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

class AutomatorWP_Fluent_Support_Client_Reply_Ticket extends AutomatorWP_Integration_Trigger {

    public $integration = 'fluent_support';
    public $trigger = 'fluent_support_client_reply_ticket';

    /**
     * Register the trigger
     *
     * @since 1.0.0
     */
    public function register() {

        automatorwp_register_trigger( $this->trigger, array(
            'integration'       => $this->integration,
            'label'             => __( 'Client replies to a ticket', 'automatorwp-fluent-support' ),
            'select_option'     => __( 'Client <strong>replies</strong> to a ticket', 'automatorwp-fluent-support' ),
            /* translators: %1$s: Number of times. */
            'edit_label'        => sprintf( __( 'Client replies to a ticket %1$s time(s)', 'automatorwp-fluent-support' ), '{times}' ),
            'log_label'         => __( 'Client replies to a ticket', 'automatorwp-fluent-support' ),
            'action'            => 'fluent_support/response_added_by_customer',
            'function'          => array( $this, 'listener' ),
            'priority'          => 10,
            'accepted_args'     => 2,
            'options'           => array(
                'times' => automatorwp_utilities_times_option()
            ),
            'tags' => array(
                automatorwp_utilities_post_tags( __( 'Ticket', 'automatorwp-fluent-support' ) ),
                'times' => automatorwp_utilities_times_tag( true )
            )
        ) );

    }

    /**
     * Trigger listener
     *
     * @since 1.0.0
     *
     * @param array $response   Replies data
     * @param array $ticket     Tickets data
     */
    public function listener( $response, $ticket ) {

        $ticket_id = absint( $ticket['id'] );
        $user = get_user_by( 'email', $ticket['customer']['email']);

        // Bail if user not found
        if( ! $user ) {
            return;
        }

        automatorwp_trigger_event( array(
            'trigger' => $this->trigger,
            'post_id' => $ticket_id,
            'user_id' => $user->ID,
        ) );

    }

}

new AutomatorWP_Fluent_Support_Client_Reply_Ticket();