<?php
/**
 * Plugin Name:           AutomatorWP - Groundhogg
 * Plugin URI:            https://automatorwp.com/add-ons/groundhogg/
 * Description:           Connect AutomatorWP with Groundhogg.
 * Version:               1.0.5
 * Author:                AutomatorWP
 * Author URI:            https://automatorwp.com/
 * Text Domain:           automatorwp-groundhogg
 * Domain Path:           /languages/
 * Requires at least:     4.4
 * Tested up to:          5.9
 * License:               GNU AGPL v3.0 (http://www.gnu.org/licenses/agpl.txt)
 *
 * @package               AutomatorWP\Groundhogg
 * @author                AutomatorWP
 * @copyright             Copyright (c) AutomatorWP
 */

final class AutomatorWP_Groundhogg {

    /**
     * @var         AutomatorWP_Groundhogg $instance The one true AutomatorWP_Groundhogg
     * @since       1.0.0
     */
    private static $instance;

    /**
     * Get active instance
     *
     * @access      public
     * @since       1.0.0
     * @return      AutomatorWP_Groundhogg self::$instance The one true AutomatorWP_Groundhogg
     */
    public static function instance() {
        if( !self::$instance ) {
            self::$instance = new AutomatorWP_Groundhogg();
            self::$instance->constants();
            self::$instance->includes();
            self::$instance->hooks();
            self::$instance->load_textdomain();
        }

        return self::$instance;
    }

    /**
     * Setup plugin constants
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function constants() {
        // Plugin version
        define( 'AUTOMATORWP_GROUNDHOGG_VER', '1.0.5' );

        // Plugin file
        define( 'AUTOMATORWP_GROUNDHOGG_FILE', __FILE__ );

        // Plugin path
        define( 'AUTOMATORWP_GROUNDHOGG_DIR', plugin_dir_path( __FILE__ ) );

        // Plugin URL
        define( 'AUTOMATORWP_GROUNDHOGG_URL', plugin_dir_url( __FILE__ ) );
    }

    /**
     * Include plugin files
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function includes() {

        if( $this->meets_requirements() ) {

            // Triggers
            require_once AUTOMATORWP_GROUNDHOGG_DIR . 'includes/triggers/tag-added.php';
            require_once AUTOMATORWP_GROUNDHOGG_DIR . 'includes/triggers/tag-removed.php';

            // Actions
            require_once AUTOMATORWP_GROUNDHOGG_DIR . 'includes/actions/create-contact.php';
            require_once AUTOMATORWP_GROUNDHOGG_DIR . 'includes/actions/user-tag.php';
            require_once AUTOMATORWP_GROUNDHOGG_DIR . 'includes/actions/create-user-tag.php';
            require_once AUTOMATORWP_GROUNDHOGG_DIR . 'includes/actions/contact-tag.php';
            require_once AUTOMATORWP_GROUNDHOGG_DIR . 'includes/actions/create-contact-tag.php';

            // Includes
            require_once AUTOMATORWP_GROUNDHOGG_DIR . 'includes/ajax-functions.php';
            require_once AUTOMATORWP_GROUNDHOGG_DIR . 'includes/functions.php';

        }
    }

    /**
     * Setup plugin hooks
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function hooks() {

        add_action( 'automatorwp_init', array( $this, 'register_integration' ) );

        add_filter( 'automatorwp_licenses_meta_boxes', array( $this, 'license' ) );

        add_action( 'admin_notices', array( $this, 'admin_notices' ) );
    }

    /**
     * Registers this integration
     *
     * @since 1.0.0
     */
    function register_integration() {

        automatorwp_register_integration( 'groundhogg', array(
            'label' => 'Groundhogg',
            'icon'  => AUTOMATORWP_GROUNDHOGG_URL . 'assets/groundhogg.svg',
        ) );

    }

    /**
     * Licensing
     *
     * @since 1.0.0
     *
     * @param array $meta_boxes
     *
     * @return array
     */
    function license( $meta_boxes ) {

        $meta_boxes['automatorwp-groundhogg-license'] = array(
            'title' => 'Groundhogg',
            'fields' => array(
                'automatorwp_groundhogg_license' => array(
                    'type' => 'edd_license',
                    'file' => AUTOMATORWP_GROUNDHOGG_FILE,
                    'item_name' => 'Groundhogg',
                ),
            )
        );

        return $meta_boxes;

    }

    /**
     * Plugin admin notices.
     *
     * @since  1.0.0
     */
    public function admin_notices() {

        if ( ! $this->meets_requirements() && ! defined( 'AUTOMATORWP_ADMIN_NOTICES' ) ) : ?>

            <div id="message" class="notice notice-error is-dismissible">
                <p>
                    <?php printf(
                        __( 'AutomatorWP - Groundhogg requires %s and %s in order to work. Please install and activate them.', 'automatorwp-groundhogg' ),
                        '<a href="https://wordpress.org/plugins/automatorwp/" target="_blank">AutomatorWP</a>',
                        '<a href="https://wordpress.org/plugins/groundhogg/" target="_blank">Groundhogg</a>'
                    ); ?>
                </p>
            </div>

            <?php define( 'AUTOMATORWP_ADMIN_NOTICES', true ); ?>

        <?php endif;

    }

    /**
     * Check if there are all plugin requirements
     *
     * @since  1.0.0
     *
     * @return bool True if installation meets all requirements
     */
    private function meets_requirements() {

        if ( ! class_exists( 'AutomatorWP' ) ) {
            return false;
        }

        if ( ! defined( 'GROUNDHOGG_VERSION' ) ) {
            return false;
        }

        return true;

    }

    /**
     * Internationalization
     *
     * @access      public
     * @since       1.0.0
     * @return      void
     */
    public function load_textdomain() {

        // Set filter for language directory
        $lang_dir = AUTOMATORWP_GROUNDHOGG_DIR . '/languages/';
        $lang_dir = apply_filters( 'automatorwp_groundhogg_languages_directory', $lang_dir );

        // Traditional WordPress plugin locale filter
        $locale = apply_filters( 'plugin_locale', get_locale(), 'automatorwp-groundhogg' );
        $mofile = sprintf( '%1$s-%2$s.mo', 'automatorwp-groundhogg', $locale );

        // Setup paths to current locale file
        $mofile_local   = $lang_dir . $mofile;
        $mofile_global  = WP_LANG_DIR . '/automatorwp-groundhogg/' . $mofile;

        if( file_exists( $mofile_global ) ) {
            // Look in global /wp-content/languages/automatorwp-groundhogg/ folder
            load_textdomain( 'automatorwp-groundhogg', $mofile_global );
        } elseif( file_exists( $mofile_local ) ) {
            // Look in local /wp-content/plugins/automatorwp-groundhogg/languages/ folder
            load_textdomain( 'automatorwp-groundhogg', $mofile_local );
        } else {
            // Load the default language files
            load_plugin_textdomain( 'automatorwp-groundhogg', false, $lang_dir );
        }

    }

}

/**
 * The main function responsible for returning the one true AutomatorWP_Groundhogg instance to functions everywhere
 *
 * @since       1.0.0
 * @return      \AutomatorWP_Groundhogg The one true AutomatorWP_Groundhogg
 */
function AutomatorWP_Groundhogg() {
    return AutomatorWP_Groundhogg::instance();
}
add_action( 'plugins_loaded', 'AutomatorWP_Groundhogg' );
