<?php
/**
 * Plugin Name:           AutomatorWP - Modern Events Calendar
 * Plugin URI:            https://automatorwp.com/add-ons/modern-events-calendar/
 * Description:           Connect AutomatorWP with Modern Events Calendar.
 * Version:               1.0.1
 * Author:                AutomatorWP
 * Author URI:            https://automatorwp.com/
 * Text Domain:           automatorwp-modern-events-calendar
 * Domain Path:           /languages/
 * Requires at least:     4.4
 * Tested up to:          5.7
 * License:               GNU AGPL v3.0 (http://www.gnu.org/licenses/agpl.txt)
 *
 * @package               AutomatorWP\Modern_Events_Calendar
 * @author                AutomatorWP
 * @copyright             Copyright (c) AutomatorWP
 */

final class AutomatorWP_Modern_Events_Calendar {

    /**
     * @var         AutomatorWP_Modern_Events_Calendar $instance The one true AutomatorWP_Modern_Events_Calendar
     * @since       1.0.0
     */
    private static $instance;

    /**
     * Get active instance
     *
     * @access      public
     * @since       1.0.0
     * @return      AutomatorWP_Modern_Events_Calendar self::$instance The one true AutomatorWP_Modern_Events_Calendar
     */
    public static function instance() {
        if( !self::$instance ) {
            self::$instance = new AutomatorWP_Modern_Events_Calendar();
            self::$instance->constants();
            self::$instance->includes();
            self::$instance->hooks();
            self::$instance->load_textdomain();
        }

        return self::$instance;
    }

    /**
     * Setup plugin constants
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function constants() {
        // Plugin version
        define( 'AUTOMATORWP_MODERN_EVENTS_CALENDAR_VER', '1.0.1' );

        // Plugin file
        define( 'AUTOMATORWP_MODERN_EVENTS_CALENDAR_FILE', __FILE__ );

        // Plugin path
        define( 'AUTOMATORWP_MODERN_EVENTS_CALENDAR_DIR', plugin_dir_path( __FILE__ ) );

        // Plugin URL
        define( 'AUTOMATORWP_MODERN_EVENTS_CALENDAR_URL', plugin_dir_url( __FILE__ ) );
    }

    /**
     * Include plugin files
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function includes() {

        if( $this->meets_requirements() ) {

            // Includes
            require_once AUTOMATORWP_MODERN_EVENTS_CALENDAR_DIR . 'includes/ajax-functions.php';
            require_once AUTOMATORWP_MODERN_EVENTS_CALENDAR_DIR . 'includes/functions.php';
            require_once AUTOMATORWP_MODERN_EVENTS_CALENDAR_DIR . 'includes/scripts.php';
            require_once AUTOMATORWP_MODERN_EVENTS_CALENDAR_DIR . 'includes/tags.php';

            // Triggers
            require_once AUTOMATORWP_MODERN_EVENTS_CALENDAR_DIR . 'includes/triggers/booking-completed.php';
            require_once AUTOMATORWP_MODERN_EVENTS_CALENDAR_DIR . 'includes/triggers/booking-pending.php';
            require_once AUTOMATORWP_MODERN_EVENTS_CALENDAR_DIR . 'includes/triggers/booking-cancelled.php';

            // Actions
            require_once AUTOMATORWP_MODERN_EVENTS_CALENDAR_DIR . 'includes/actions/book-user.php';
        }
    }

    /**
     * Setup plugin hooks
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function hooks() {

        add_action( 'automatorwp_init', array( $this, 'register_integration' ) );

        add_filter( 'automatorwp_licenses_meta_boxes', array( $this, 'license' ) );

        add_action( 'admin_notices', array( $this, 'admin_notices' ) );
    }

    /**
     * Registers this integration
     *
     * @since 1.0.0
     */
    function register_integration() {

        automatorwp_register_integration( 'modern_events_calendar', array(
            'label' => 'Modern Events Calendar',
            'icon'  => AUTOMATORWP_MODERN_EVENTS_CALENDAR_URL . 'assets/modern-events-calendar.svg',
        ) );

    }

    /**
     * Licensing
     *
     * @since 1.0.0
     *
     * @param array $meta_boxes
     *
     * @return array
     */
    function license( $meta_boxes ) {

        $meta_boxes['automatorwp-modern-events-calendar-license'] = array(
            'title' => 'Modern Events Calendar',
            'fields' => array(
                'automatorwp_modern_events_calendar_license' => array(
                    'type' => 'edd_license',
                    'file' => AUTOMATORWP_MODERN_EVENTS_CALENDAR_FILE,
                    'item_name' => 'Modern Events Calendar',
                ),
            )
        );

        return $meta_boxes;

    }

    /**
     * Plugin admin notices.
     *
     * @since  1.0.0
     */
    public function admin_notices() {

        if ( ! $this->meets_requirements() && ! defined( 'AUTOMATORWP_ADMIN_NOTICES' ) ) : ?>

            <div id="message" class="notice notice-error is-dismissible">
                <p>
                    <?php printf(
                        __( 'AutomatorWP - Modern Events Calendar requires %s and %s in order to work. Please install and activate them.', 'automatorwp-modern-events-calendar' ),
                        '<a href="https://wordpress.org/plugins/automatorwp/" target="_blank">AutomatorWP</a>',
                        '<a href="https://wordpress.org/plugins/modern-events-calendar-lite/" target="_blank">Modern Events Calendar</a>'
                    ); ?>
                </p>
            </div>

            <?php define( 'AUTOMATORWP_ADMIN_NOTICES', true ); ?>

        <?php endif;

    }

    /**
     * Check if there are all plugin requirements
     *
     * @since  1.0.0
     *
     * @return bool True if installation meets all requirements
     */
    private function meets_requirements() {

        if ( ! class_exists( 'AutomatorWP' ) ) {
            return false;
        }

        if ( ! class_exists( 'MEC' ) ) {
            return false;
        }

        return true;

    }

    /**
     * Internationalization
     *
     * @access      public
     * @since       1.0.0
     * @return      void
     */
    public function load_textdomain() {

        // Set filter for language directory
        $lang_dir = AUTOMATORWP_MODERN_EVENTS_CALENDAR_DIR . '/languages/';
        $lang_dir = apply_filters( 'automatorwp_modern_events_calendar_languages_directory', $lang_dir );

        // Traditional WordPress plugin locale filter
        $locale = apply_filters( 'plugin_locale', get_locale(), 'automatorwp-modern-events-calendar' );
        $mofile = sprintf( '%1$s-%2$s.mo', 'automatorwp-modern-events-calendar', $locale );

        // Setup paths to current locale file
        $mofile_local   = $lang_dir . $mofile;
        $mofile_global  = WP_LANG_DIR . '/automatorwp-modern-events-calendar/' . $mofile;

        if( file_exists( $mofile_global ) ) {
            // Look in global /wp-content/languages/automatorwp-modern-events-calendar/ folder
            load_textdomain( 'automatorwp-modern-events-calendar', $mofile_global );
        } elseif( file_exists( $mofile_local ) ) {
            // Look in local /wp-content/plugins/automatorwp-modern-events-calendar/languages/ folder
            load_textdomain( 'automatorwp-modern-events-calendar', $mofile_local );
        } else {
            // Load the default language files
            load_plugin_textdomain( 'automatorwp-modern-events-calendar', false, $lang_dir );
        }

    }

}

/**
 * The main function responsible for returning the one true AutomatorWP_Modern_Events_Calendar instance to functions everywhere
 *
 * @since       1.0.0
 * @return      \AutomatorWP_Modern_Events_Calendar The one true AutomatorWP_Modern_Events_Calendar
 */
function AutomatorWP_Modern_Events_Calendar() {
    return AutomatorWP_Modern_Events_Calendar::instance();
}
add_action( 'plugins_loaded', 'AutomatorWP_Modern_Events_Calendar' );
