<?php
/**
 * Watch Video
 *
 * @package     AutomatorWP\Integrations\WordPress\Triggers\Watch_Video
 * @author      AutomatorWP <contact@automatorwp.com>, Ruben Garcia <rubengcdev@gmail.com>
 * @since       1.0.0
 */
// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

class AutomatorWP_WordPress_Watch_Video extends AutomatorWP_Integration_Trigger {

    public $integration = 'wordpress';
    public $trigger = 'wordpress_watch_video';

    /**
     * Register the trigger
     *
     * @since 1.0.0
     */
    public function register() {

        automatorwp_register_trigger( $this->trigger, array(
            'integration'       => $this->integration,
            'label'             => __( 'User watches a video', 'automatorwp-multimedia-content' ),
            'select_option'     => __( 'User watches a <strong>video</strong>', 'automatorwp-multimedia-content' ),
            /* translators: %1$s: Post title. %2$s: Number of times. */
            'edit_label'        => sprintf( __( 'User watches %1$s %2$s time(s)', 'automatorwp-multimedia-content' ), '{post}', '{times}' ),
            /* translators: %1$s: Post title. */
            'log_label'         => sprintf( __( 'User watches %1$s file', 'automatorwp-multimedia-content' ), '{post}' ),
            'action'            => 'automatorwp_multimedia_content_watch_video',
            'function'          => array( $this, 'listener' ),
            'priority'          => 10,
            'accepted_args'     => 5,
            'options'           => array(
                'post' => automatorwp_utilities_post_option( array(
                    'name' => __( 'Video:', 'automatorwp-multimedia-content' ),
                    'option_none_label' => __( 'any video', 'automatorwp-multimedia-content' ),
                    'post_type' => 'video'
                ) ),
                'times' => automatorwp_utilities_times_option(),
            ),
            'tags' => array_merge(
                automatorwp_utilities_times_tag()
            )
        ) );

    }

    /**
     * Trigger listener
     *
     * @since 1.0.0
     *
     * @param int $attachment_id The attachment ID
     * @param int $user_id The user ID
     * @param int $post_id The post ID
     * @param int $post_author The attachemnt author ID
     * @param WP_Post $attachment The attachment object
     */
    public function listener( $attachment_id, $user_id, $post_id, $post_author, $attachment ) {

        // Bail if is the attachment author
        if( $post_author === $user_id ) {
            return;
        }

        // Trigger likes
        automatorwp_trigger_event( array(
            'trigger'           => $this->trigger,
            'user_id'           => $user_id,
            'post_id'           => $attachment_id,
        ) );

    }

    /**
     * User deserves check
     *
     * @since 1.0.0
     *
     * @param bool      $deserves_trigger   True if user deserves trigger, false otherwise
     * @param stdClass  $trigger            The trigger object
     * @param int       $user_id            The user ID
     * @param array     $event              Event information
     * @param array     $trigger_options    The trigger's stored options
     * @param stdClass  $automation         The trigger's automation object
     *
     * @return bool                          True if user deserves trigger, false otherwise
     */
    public function user_deserves_trigger( $deserves_trigger, $trigger, $user_id, $event, $trigger_options, $automation ) {

        // Don't deserve if post is not received
        if( ! isset( $event['post_id'] ) ) {
            return false;
        }

        // Don't deserve if post doesn't match with the trigger option
        if( ! automatorwp_posts_matches( $event['post_id'], $trigger_options['post'] ) ) {
            return false;
        }

        return $deserves_trigger;

    }

}

new AutomatorWP_WordPress_Watch_Video();