<?php
/**
 * Plugin Name:           AutomatorWP - Newsletter
 * Plugin URI:            https://automatorwp.com/add-ons/newsletter/
 * Description:           Connect AutomatorWP with Newsletter.
 * Version:               1.0.2
 * Author:                AutomatorWP
 * Author URI:            https://automatorwp.com/
 * Text Domain:           automatorwp-newsletter
 * Domain Path:           /languages/
 * Requires at least:     4.4
 * Tested up to:          5.9
 * License:               GNU AGPL v3.0 (http://www.gnu.org/licenses/agpl.txt)
 *
 * @package               AutomatorWP\Newsletter
 * @author                AutomatorWP
 * @copyright             Copyright (c) AutomatorWP
 */

final class AutomatorWP_Newsletter {

    /**
     * @var         AutomatorWP_Newsletter $instance The one true AutomatorWP_Newsletter
     * @since       1.0.0
     */
    private static $instance;

    /**
     * Get active instance
     *
     * @access      public
     * @since       1.0.0
     * @return      AutomatorWP_Newsletter self::$instance The one true AutomatorWP_Newsletter
     */
    public static function instance() {
        if( !self::$instance ) {

            self::$instance = new AutomatorWP_Newsletter();
            self::$instance->constants();
            self::$instance->includes();
            self::$instance->hooks();

        }

        return self::$instance;
    }

    /**
     * Setup plugin constants
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function constants() {
        // Plugin version
        define( 'AUTOMATORWP_NEWSLETTER_VER', '1.0.2' );

        // Plugin file
        define( 'AUTOMATORWP_NEWSLETTER_FILE', __FILE__ );

        // Plugin path
        define( 'AUTOMATORWP_NEWSLETTER_DIR', plugin_dir_path( __FILE__ ) );

        // Plugin URL
        define( 'AUTOMATORWP_NEWSLETTER_URL', plugin_dir_url( __FILE__ ) );
    }

    /**
     * Include plugin files
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function includes() {

        if( $this->meets_requirements() ) {

            // Triggers
            require_once AUTOMATORWP_NEWSLETTER_DIR . 'includes/triggers/anonymous-subscribe-list.php';

            // Actions
            require_once AUTOMATORWP_NEWSLETTER_DIR . 'includes/actions/add-user-to-list.php';
            require_once AUTOMATORWP_NEWSLETTER_DIR . 'includes/actions/remove-user-from-list.php';

        }
    }

    /**
     * Setup plugin hooks
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function hooks() {

        add_action( 'automatorwp_init', array( $this, 'register_integration' ) );

        add_filter( 'automatorwp_licenses_meta_boxes', array( $this, 'license' ) );

        add_action( 'admin_notices', array( $this, 'admin_notices' ) );
    }

    /**
     * Registers this integration
     *
     * @since 1.0.0
     */
    function register_integration() {

        automatorwp_register_integration( 'newsletter', array(
            'label' => 'Newsletter',
            'icon'  => AUTOMATORWP_NEWSLETTER_URL . 'assets/newsletter.svg',
        ) );

    }

    /**
     * Licensing
     *
     * @since 1.0.0
     *
     * @param array $meta_boxes
     *
     * @return array
     */
    function license( $meta_boxes ) {

        $meta_boxes['automatorwp-newsletter-license'] = array(
            'title' => 'Newsletter',
            'fields' => array(
                'automatorwp_newsletter_license' => array(
                    'type' => 'edd_license',
                    'file' => AUTOMATORWP_NEWSLETTER_FILE,
                    'item_name' => 'Newsletter',
                ),
            )
        );

        return $meta_boxes;

    }

    /**
     * Plugin admin notices.
     *
     * @since  1.0.0
     */
    public function admin_notices() {

        if ( ! $this->meets_requirements() && ! defined( 'AUTOMATORWP_ADMIN_NOTICES' ) ) : ?>

            <div id="message" class="notice notice-error is-dismissible">
                <p>
                    <?php printf(
                        __( 'AutomatorWP - Newsletter requires %s and %s in order to work. Please install and activate them.', 'automatorwp-newsletter' ),
                        '<a href="https://wordpress.org/plugins/automatorwp/" target="_blank">AutomatorWP</a>',
                        '<a href="https://wordpress.org/plugins/newsletter/" target="_blank">Newsletter</a>'
                    ); ?>
                </p>
            </div>

            <?php define( 'AUTOMATORWP_ADMIN_NOTICES', true ); ?>

        <?php endif;

    }

    /**
     * Check if there are all plugin requirements
     *
     * @since  1.0.0
     *
     * @return bool True if installation meets all requirements
     */
    private function meets_requirements() {

        if ( ! class_exists( 'AutomatorWP' ) ) {
            return false;
        }

        if ( ! defined( 'NEWSLETTER_VERSION' ) ) {
            return false;
        }

        return true;

    }

}

/**
 * The main function responsible for returning the one true AutomatorWP_Newsletter instance to functions everywhere
 *
 * @since       1.0.0
 * @return      \AutomatorWP_Newsletter The one true AutomatorWP_Newsletter
 */
function AutomatorWP_Newsletter() {
    return AutomatorWP_Newsletter::instance();
}
add_action( 'automatorwp_pre_init', 'AutomatorWP_Newsletter' );
