<?php
/**
 * Plugin Name:           AutomatorWP - Paid Memberships Pro
 * Plugin URI:            https://automatorwp.com/add-ons/paid-memberships-pro/
 * Description:           Connect AutomatorWP with Paid Memberships Pro.
 * Version:               1.0.5
 * Author:                AutomatorWP
 * Author URI:            https://automatorwp.com/
 * Text Domain:           automatorwp-paid-memberships-pro
 * Domain Path:           /languages/
 * Requires at least:     4.4
 * Tested up to:          5.9
 * License:               GNU AGPL v3.0 (http://www.gnu.org/licenses/agpl.txt)
 *
 * @package               AutomatorWP\Paid_Memberships_Pro
 * @author                AutomatorWP
 * @copyright             Copyright (c) AutomatorWP
 */

final class AutomatorWP_Paid_Memberships_Pro {

    /**
     * @var         AutomatorWP_Paid_Memberships_Pro $instance The one true AutomatorWP_Paid_Memberships_Pro
     * @since       1.0.0
     */
    private static $instance;

    /**
     * Get active instance
     *
     * @access      public
     * @since       1.0.0
     * @return      AutomatorWP_Paid_Memberships_Pro self::$instance The one true AutomatorWP_Paid_Memberships_Pro
     */
    public static function instance() {
        if( !self::$instance ) {
            self::$instance = new AutomatorWP_Paid_Memberships_Pro();
            self::$instance->constants();
            self::$instance->includes();
            self::$instance->hooks();
            self::$instance->load_textdomain();
        }

        return self::$instance;
    }

    /**
     * Setup plugin constants
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function constants() {
        // Plugin version
        define( 'AUTOMATORWP_PAID_MEMBERSHIPS_PRO_VER', '1.0.5' );

        // Plugin file
        define( 'AUTOMATORWP_PAID_MEMBERSHIPS_PRO_FILE', __FILE__ );

        // Plugin path
        define( 'AUTOMATORWP_PAID_MEMBERSHIPS_PRO_DIR', plugin_dir_path( __FILE__ ) );

        // Plugin URL
        define( 'AUTOMATORWP_PAID_MEMBERSHIPS_PRO_URL', plugin_dir_url( __FILE__ ) );
    }

    /**
     * Include plugin files
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function includes() {

        if( $this->meets_requirements() ) {

            // Includes
            require_once AUTOMATORWP_PAID_MEMBERSHIPS_PRO_DIR . 'includes/ajax-functions.php';
            require_once AUTOMATORWP_PAID_MEMBERSHIPS_PRO_DIR . 'includes/functions.php';

            // Triggers
            require_once AUTOMATORWP_PAID_MEMBERSHIPS_PRO_DIR . 'includes/triggers/purchase-membership.php';
            require_once AUTOMATORWP_PAID_MEMBERSHIPS_PRO_DIR . 'includes/triggers/renew-membership.php';
            require_once AUTOMATORWP_PAID_MEMBERSHIPS_PRO_DIR . 'includes/triggers/cancel-subscription.php';
            require_once AUTOMATORWP_PAID_MEMBERSHIPS_PRO_DIR . 'includes/triggers/subscription-expired.php';

            // Actions
            require_once AUTOMATORWP_PAID_MEMBERSHIPS_PRO_DIR . 'includes/actions/add-user-membership.php';
            require_once AUTOMATORWP_PAID_MEMBERSHIPS_PRO_DIR . 'includes/actions/remove-user-membership.php';

        }
    }

    /**
     * Setup plugin hooks
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function hooks() {

        add_action( 'automatorwp_init', array( $this, 'register_integration' ) );

        add_filter( 'automatorwp_licenses_meta_boxes', array( $this, 'license' ) );

        add_action( 'admin_notices', array( $this, 'admin_notices' ) );
    }

    /**
     * Registers this integration
     *
     * @since 1.0.0
     */
    function register_integration() {

        automatorwp_register_integration( 'paid_memberships_pro', array(
            'label' => 'Paid Memberships Pro',
            'icon'  => AUTOMATORWP_PAID_MEMBERSHIPS_PRO_URL . 'assets/paid-memberships-pro.svg',
        ) );

    }

    /**
     * Licensing
     *
     * @since 1.0.0
     *
     * @param array $meta_boxes
     *
     * @return array
     */
    function license( $meta_boxes ) {

        $meta_boxes['automatorwp-paid-memberships-pro-license'] = array(
            'title' => 'Paid Memberships Pro',
            'fields' => array(
                'automatorwp_paid_memberships_pro_license' => array(
                    'type' => 'edd_license',
                    'file' => AUTOMATORWP_PAID_MEMBERSHIPS_PRO_FILE,
                    'item_name' => 'Paid Memberships Pro',
                ),
            )
        );

        return $meta_boxes;

    }

    /**
     * Plugin admin notices.
     *
     * @since  1.0.0
     */
    public function admin_notices() {

        if ( ! $this->meets_requirements() && ! defined( 'AUTOMATORWP_ADMIN_NOTICES' ) ) : ?>

            <div id="message" class="notice notice-error is-dismissible">
                <p>
                    <?php printf(
                        __( 'AutomatorWP - Paid Memberships Pro requires %s and %s in order to work. Please install and activate them.', 'automatorwp-paid-memberships-pro' ),
                        '<a href="https://wordpress.org/plugins/automatorwp/" target="_blank">AutomatorWP</a>',
                        '<a href="https://wordpress.org/plugins/paid-memberships-pro/" target="_blank">Paid Memberships Pro</a>'
                    ); ?>
                </p>
            </div>

            <?php define( 'AUTOMATORWP_ADMIN_NOTICES', true ); ?>

        <?php endif;

    }

    /**
     * Check if there are all plugin requirements
     *
     * @since  1.0.0
     *
     * @return bool True if installation meets all requirements
     */
    private function meets_requirements() {

        if ( ! class_exists( 'AutomatorWP' ) ) {
            return false;
        }

        if ( ! function_exists( 'pmpro_init' ) ) {
            return false;
        }

        return true;

    }

    /**
     * Internationalization
     *
     * @access      public
     * @since       1.0.0
     * @return      void
     */
    public function load_textdomain() {

        // Set filter for language directory
        $lang_dir = AUTOMATORWP_PAID_MEMBERSHIPS_PRO_DIR . '/languages/';
        $lang_dir = apply_filters( 'automatorwp_paid_memberships_pro_languages_directory', $lang_dir );

        // Traditional WordPress plugin locale filter
        $locale = apply_filters( 'plugin_locale', get_locale(), 'automatorwp-paid-memberships-pro' );
        $mofile = sprintf( '%1$s-%2$s.mo', 'automatorwp-paid-memberships-pro', $locale );

        // Setup paths to current locale file
        $mofile_local   = $lang_dir . $mofile;
        $mofile_global  = WP_LANG_DIR . '/automatorwp-paid-memberships-pro/' . $mofile;

        if( file_exists( $mofile_global ) ) {
            // Look in global /wp-content/languages/automatorwp-paid-memberships-pro/ folder
            load_textdomain( 'automatorwp-paid-memberships-pro', $mofile_global );
        } elseif( file_exists( $mofile_local ) ) {
            // Look in local /wp-content/plugins/automatorwp-paid-memberships-pro/languages/ folder
            load_textdomain( 'automatorwp-paid-memberships-pro', $mofile_local );
        } else {
            // Load the default language files
            load_plugin_textdomain( 'automatorwp-paid-memberships-pro', false, $lang_dir );
        }

    }

}

/**
 * The main function responsible for returning the one true AutomatorWP_Paid_Memberships_Pro instance to functions everywhere
 *
 * @since       1.0.0
 * @return      \AutomatorWP_Paid_Memberships_Pro The one true AutomatorWP_Paid_Memberships_Pro
 */
function AutomatorWP_Paid_Memberships_Pro() {
    return AutomatorWP_Paid_Memberships_Pro::instance();
}
add_action( 'plugins_loaded', 'AutomatorWP_Paid_Memberships_Pro' );
