<?php
/**
 * Plugin Name:           AutomatorWP - SliceWP
 * Plugin URI:            https://automatorwp.com/add-ons/slicewp/
 * Description:           Connect AutomatorWP with SliceWP.
 * Version:               1.0.1
 * Author:                AutomatorWP
 * Author URI:            https://automatorwp.com/
 * Text Domain:           automatorwp-slicewp
 * Domain Path:           /languages/
 * Requires at least:     4.4
 * Tested up to:          5.8
 * License:               GNU AGPL v3.0 (http://www.gnu.org/licenses/agpl.txt)
 *
 * @package               AutomatorWP\SliceWP
 * @author                AutomatorWP
 * @copyright             Copyright (c) AutomatorWP
 */

final class AutomatorWP_SliceWP {

    /**
     * @var         AutomatorWP_SliceWP $instance The one true AutomatorWP_SliceWP
     * @since       1.0.0
     */
    private static $instance;

    /**
     * Get active instance
     *
     * @access      public
     * @since       1.0.0
     * @return      AutomatorWP_SliceWP self::$instance The one true AutomatorWP_SliceWP
     */
    public static function instance() {
        if( !self::$instance ) {
            self::$instance = new AutomatorWP_SliceWP();
            self::$instance->constants();
            self::$instance->includes();
            self::$instance->hooks();
            self::$instance->load_textdomain();
        }

        return self::$instance;
    }

    /**
     * Setup plugin constants
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function constants() {
        // Plugin version
        define( 'AUTOMATORWP_SLICEWP_VER', '1.0.1' );

        // Plugin file
        define( 'AUTOMATORWP_SLICEWP_FILE', __FILE__ );

        // Plugin path
        define( 'AUTOMATORWP_SLICEWP_DIR', plugin_dir_path( __FILE__ ) );

        // Plugin URL
        define( 'AUTOMATORWP_SLICEWP_URL', plugin_dir_url( __FILE__ ) );
    }

    /**
     * Include plugin files
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function includes() {

        if( $this->meets_requirements() ) {

            // Includes
            require_once AUTOMATORWP_SLICEWP_DIR . 'includes/functions.php';
            require_once AUTOMATORWP_SLICEWP_DIR . 'includes/tags.php';

            // Triggers
            require_once AUTOMATORWP_SLICEWP_DIR . 'includes/triggers/become-affiliate.php';
            require_once AUTOMATORWP_SLICEWP_DIR . 'includes/triggers/earn-commission.php';
            require_once AUTOMATORWP_SLICEWP_DIR . 'includes/triggers/commission.php';

            // Actions
            require_once AUTOMATORWP_SLICEWP_DIR . 'includes/actions/add-commission.php';
            require_once AUTOMATORWP_SLICEWP_DIR . 'includes/actions/add-commission-to-affiliate.php';

        }
    }

    /**
     * Setup plugin hooks
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function hooks() {

        add_action( 'automatorwp_init', array( $this, 'register_integration' ) );

        add_filter( 'automatorwp_licenses_meta_boxes', array( $this, 'license' ) );

        // Setup our activation and deactivation hooks
        register_activation_hook( __FILE__, array( $this, 'activate' ) );
        register_deactivation_hook( __FILE__, array( $this, 'deactivate' ) );

        add_action( 'admin_notices', array( $this, 'admin_notices' ) );
    }

    /**
     * Registers this integration
     *
     * @since 1.0.0
     */
    function register_integration() {

        automatorwp_register_integration( 'slicewp', array(
            'label' => 'SliceWP',
            'icon'  => AUTOMATORWP_SLICEWP_URL . 'assets/slicewp.svg',
        ) );

    }

    /**
     * Licensing
     *
     * @since 1.0.0
     *
     * @param array $meta_boxes
     *
     * @return array
     */
    function license( $meta_boxes ) {

        $meta_boxes['automatorwp-slicewp-license'] = array(
            'title' => 'SliceWP',
            'fields' => array(
                'automatorwp_slicewp_license' => array(
                    'type' => 'edd_license',
                    'file' => AUTOMATORWP_SLICEWP_FILE,
                    'item_name' => 'SliceWP',
                ),
            )
        );

        return $meta_boxes;

    }

    /**
     * Activation hook for the plugin.
     *
     * @since  1.0.0
     */
    function activate() {

        if( $this->meets_requirements() ) {

        }

    }

    /**
     * Deactivation hook for the plugin.
     *
     * @since  1.0.0
     */
    function deactivate() {

    }

    /**
     * Plugin admin notices.
     *
     * @since  1.0.0
     */
    public function admin_notices() {

        if ( ! $this->meets_requirements() && ! defined( 'AUTOMATORWP_ADMIN_NOTICES' ) ) : ?>

            <div id="message" class="notice notice-error is-dismissible">
                <p>
                    <?php printf(
                        __( 'AutomatorWP - SliceWP requires %s and %s in order to work. Please install and activate them.', 'automatorwp-slicewp' ),
                        '<a href="https://wordpress.org/plugins/automatorwp/" target="_blank">AutomatorWP</a>',
                        '<a href="https://wordpress.org/plugins/slicewp/" target="_blank">SliceWP</a>'
                    ); ?>
                </p>
            </div>

            <?php define( 'AUTOMATORWP_ADMIN_NOTICES', true ); ?>

        <?php endif;

    }

    /**
     * Check if there are all plugin requirements
     *
     * @since  1.0.0
     *
     * @return bool True if installation meets all requirements
     */
    private function meets_requirements() {

        if ( ! class_exists( 'AutomatorWP' ) ) {
            return false;
        }

        if ( ! class_exists( 'SliceWP' ) ) {
            return false;
        }

        return true;

    }

    /**
     * Internationalization
     *
     * @access      public
     * @since       1.0.0
     * @return      void
     */
    public function load_textdomain() {

        // Set filter for language directory
        $lang_dir = AUTOMATORWP_SLICEWP_DIR . '/languages/';
        $lang_dir = apply_filters( 'automatorwp_slicewp_languages_directory', $lang_dir );

        // Traditional WordPress plugin locale filter
        $locale = apply_filters( 'plugin_locale', get_locale(), 'automatorwp-slicewp' );
        $mofile = sprintf( '%1$s-%2$s.mo', 'automatorwp-slicewp', $locale );

        // Setup paths to current locale file
        $mofile_local   = $lang_dir . $mofile;
        $mofile_global  = WP_LANG_DIR . '/automatorwp-slicewp/' . $mofile;

        if( file_exists( $mofile_global ) ) {
            // Look in global /wp-content/languages/automatorwp-slicewp/ folder
            load_textdomain( 'automatorwp-slicewp', $mofile_global );
        } elseif( file_exists( $mofile_local ) ) {
            // Look in local /wp-content/plugins/automatorwp-slicewp/languages/ folder
            load_textdomain( 'automatorwp-slicewp', $mofile_local );
        } else {
            // Load the default language files
            load_plugin_textdomain( 'automatorwp-slicewp', false, $lang_dir );
        }

    }

}

/**
 * The main function responsible for returning the one true AutomatorWP_SliceWP instance to functions everywhere
 *
 * @since       1.0.0
 * @return      \AutomatorWP_SliceWP The one true AutomatorWP_SliceWP
 */
function AutomatorWP_SliceWP() {
    return AutomatorWP_SliceWP::instance();
}
add_action( 'plugins_loaded', 'AutomatorWP_SliceWP' );
