<?php
/**
 * Update Information
 *
 * @package     AutomatorWP\Integrations\Ultimate_Member\Triggers\Update_Information
 * @author      AutomatorWP <contact@automatorwp.com>, Ruben Garcia <rubengcdev@gmail.com>
 * @since       1.0.0
 */
// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

class AutomatorWP_Ultimate_Member_Update_Information extends AutomatorWP_Integration_Trigger {

    public $integration = 'ultimate_member';
    public $trigger = 'ultimate_member_update_information';

    /**
     * Register the trigger
     *
     * @since 1.0.0
     */
    public function register() {

        automatorwp_register_trigger( $this->trigger, array(
            'integration'       => $this->integration,
            'label'             => __( 'User updates account information', 'automatorwp-ultimate-member' ),
            'select_option'     => __( 'User updates <strong>account information</strong>', 'automatorwp-ultimate-member' ),
            /* translators: %1$s: Number of times. */
            'edit_label'        => sprintf( __( 'User updates account information %1$s time(s)', 'automatorwp-ultimate-member' ), '{times}' ),
            'log_label'         => __( 'User updates account information', 'automatorwp-ultimate-member' ),
            'action'            => 'um_after_user_account_updated',
            'function'          => array( $this, 'listener' ),
            'priority'          => 10,
            'accepted_args'     => 2,
            'options'           => array(
                'times' => automatorwp_utilities_times_option(),
            ),
            'tags' => array_merge(
                automatorwp_utilities_times_tag()
            )
        ) );

    }

    /**
     * Trigger listener
     *
     * @since 1.0.0
     *
     * @param int       $user_id    The user ID
     * @param array     $changes    Fields changed
     */
    public function listener( $user_id, $changes ) {

        automatorwp_trigger_event( array(
            'trigger'       => $this->trigger,
            'user_id'       => $user_id,
        ) );

    }

}

new AutomatorWP_Ultimate_Member_Update_Information();