<?php
/**
 * Plugin Name:           AutomatorWP - WishList Member
 * Plugin URI:            https://automatorwp.com/add-ons/wishlist-member/
 * Description:           Connect AutomatorWP with WishList Member.
 * Version:               1.0.3
 * Author:                AutomatorWP
 * Author URI:            https://automatorwp.com/
 * Text Domain:           automatorwp-wishlist-member
 * Domain Path:           /languages/
 * Requires at least:     4.4
 * Tested up to:          5.6
 * License:               GNU AGPL v3.0 (http://www.gnu.org/licenses/agpl.txt)
 *
 * @package               AutomatorWP\WishList_Member
 * @author                AutomatorWP
 * @copyright             Copyright (c) AutomatorWP
 */

final class AutomatorWP_WishList_Member {

    /**
     * @var         AutomatorWP_WishList_Member $instance The one true AutomatorWP_WishList_Member
     * @since       1.0.0
     */
    private static $instance;

    /**
     * Get active instance
     *
     * @access      public
     * @since       1.0.0
     * @return      AutomatorWP_WishList_Member self::$instance The one true AutomatorWP_WishList_Member
     */
    public static function instance() {
        if( !self::$instance ) {
            self::$instance = new AutomatorWP_WishList_Member();
            self::$instance->constants();
            self::$instance->includes();
            self::$instance->hooks();
            self::$instance->load_textdomain();
        }

        return self::$instance;
    }

    /**
     * Setup plugin constants
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function constants() {
        // Plugin version
        define( 'AUTOMATORWP_WISHLIST_MEMBER_VER', '1.0.3' );

        // Plugin file
        define( 'AUTOMATORWP_WISHLIST_MEMBER_FILE', __FILE__ );

        // Plugin path
        define( 'AUTOMATORWP_WISHLIST_MEMBER_DIR', plugin_dir_path( __FILE__ ) );

        // Plugin URL
        define( 'AUTOMATORWP_WISHLIST_MEMBER_URL', plugin_dir_url( __FILE__ ) );
    }

    /**
     * Include plugin files
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function includes() {

        if( $this->meets_requirements() ) {

            // Includes
            require_once AUTOMATORWP_WISHLIST_MEMBER_DIR . 'includes/functions.php';

            // Triggers
            require_once AUTOMATORWP_WISHLIST_MEMBER_DIR . 'includes/triggers/add-level.php';
            require_once AUTOMATORWP_WISHLIST_MEMBER_DIR . 'includes/triggers/remove-level.php';
            require_once AUTOMATORWP_WISHLIST_MEMBER_DIR . 'includes/triggers/approve-level.php';
            require_once AUTOMATORWP_WISHLIST_MEMBER_DIR . 'includes/triggers/unapprove-level.php';
            require_once AUTOMATORWP_WISHLIST_MEMBER_DIR . 'includes/triggers/cancel-level.php';
            require_once AUTOMATORWP_WISHLIST_MEMBER_DIR . 'includes/triggers/uncancel-level.php';

            // Actions
            require_once AUTOMATORWP_WISHLIST_MEMBER_DIR . 'includes/actions/user-level.php';

        }
    }

    /**
     * Setup plugin hooks
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function hooks() {

        add_action( 'automatorwp_init', array( $this, 'register_integration' ) );

        add_filter( 'automatorwp_licenses_meta_boxes', array( $this, 'license' ) );

        // Setup our activation and deactivation hooks
        register_activation_hook( __FILE__, array( $this, 'activate' ) );
        register_deactivation_hook( __FILE__, array( $this, 'deactivate' ) );

        add_action( 'admin_notices', array( $this, 'admin_notices' ) );
    }

    /**
     * Registers this integration
     *
     * @since 1.0.0
     */
    function register_integration() {

        automatorwp_register_integration( 'wishlist_member', array(
            'label' => 'WishList Member',
            'icon'  => AUTOMATORWP_WISHLIST_MEMBER_URL . 'assets/wishlist-member.svg',
        ) );

    }

    /**
     * Licensing
     *
     * @since 1.0.0
     *
     * @param array $meta_boxes
     *
     * @return array
     */
    function license( $meta_boxes ) {

        $meta_boxes['automatorwp-wishlist-member-license'] = array(
            'title' => 'WishList Member',
            'fields' => array(
                'automatorwp_wishlist_member_license' => array(
                    'type' => 'edd_license',
                    'file' => AUTOMATORWP_WISHLIST_MEMBER_FILE,
                    'item_name' => 'WishList Member',
                ),
            )
        );

        return $meta_boxes;

    }

    /**
     * Activation hook for the plugin.
     *
     * @since  1.0.0
     */
    function activate() {

        if( $this->meets_requirements() ) {

        }

    }

    /**
     * Deactivation hook for the plugin.
     *
     * @since  1.0.0
     */
    function deactivate() {

    }

    /**
     * Plugin admin notices.
     *
     * @since  1.0.0
     */
    public function admin_notices() {

        if ( ! $this->meets_requirements() && ! defined( 'AUTOMATORWP_ADMIN_NOTICES' ) ) : ?>

            <div id="message" class="notice notice-error is-dismissible">
                <p>
                    <?php printf(
                        __( 'AutomatorWP - WishList Member requires %s and %s in order to work. Please install and activate them.', 'automatorwp-wishlist-member' ),
                        '<a href="https://wordpress.org/plugins/automatorwp/" target="_blank">AutomatorWP</a>',
                        '<a href="https://member.wishlistproducts.com/" target="_blank">WishList Member</a>'
                    ); ?>
                </p>
            </div>

            <?php define( 'AUTOMATORWP_ADMIN_NOTICES', true ); ?>

        <?php endif;

    }

    /**
     * Check if there are all plugin requirements
     *
     * @since  1.0.0
     *
     * @return bool True if installation meets all requirements
     */
    private function meets_requirements() {

        if ( ! class_exists( 'AutomatorWP' ) ) {
            return false;
        }

        if ( ! class_exists( 'WishListMember' ) ) {
            return false;
        }

        return true;

    }

    /**
     * Internationalization
     *
     * @access      public
     * @since       1.0.0
     * @return      void
     */
    public function load_textdomain() {

        // Set filter for language directory
        $lang_dir = AUTOMATORWP_WISHLIST_MEMBER_DIR . '/languages/';
        $lang_dir = apply_filters( 'automatorwp_wishlist_member_languages_directory', $lang_dir );

        // Traditional WordPress plugin locale filter
        $locale = apply_filters( 'plugin_locale', get_locale(), 'automatorwp-wishlist-member' );
        $mofile = sprintf( '%1$s-%2$s.mo', 'automatorwp-wishlist-member', $locale );

        // Setup paths to current locale file
        $mofile_local   = $lang_dir . $mofile;
        $mofile_global  = WP_LANG_DIR . '/automatorwp-wishlist-member/' . $mofile;

        if( file_exists( $mofile_global ) ) {
            // Look in global /wp-content/languages/automatorwp-wishlist-member/ folder
            load_textdomain( 'automatorwp-wishlist-member', $mofile_global );
        } elseif( file_exists( $mofile_local ) ) {
            // Look in local /wp-content/plugins/automatorwp-wishlist-member/languages/ folder
            load_textdomain( 'automatorwp-wishlist-member', $mofile_local );
        } else {
            // Load the default language files
            load_plugin_textdomain( 'automatorwp-wishlist-member', false, $lang_dir );
        }

    }

}

/**
 * The main function responsible for returning the one true AutomatorWP_WishList_Member instance to functions everywhere
 *
 * @since       1.0.0
 * @return      \AutomatorWP_WishList_Member The one true AutomatorWP_WishList_Member
 */
function AutomatorWP_WishList_Member() {
    return AutomatorWP_WishList_Member::instance();
}
add_action( 'plugins_loaded', 'AutomatorWP_WishList_Member' );
