<?php
/**
 * Plugin Name:           AutomatorWP - WP Job Manager
 * Plugin URI:            https://automatorwp.com/add-ons/wp-job-manager/
 * Description:           Connect AutomatorWP with WP Job Manager.
 * Version:               1.0.2
 * Author:                AutomatorWP
 * Author URI:            https://automatorwp.com/
 * Text Domain:           automatorwp-wp-job-manager
 * Domain Path:           /languages/
 * Requires at least:     4.4
 * Tested up to:          5.8
 * License:               GNU AGPL v3.0 (http://www.gnu.org/licenses/agpl.txt)
 *
 * @package               AutomatorWP\WP_Job_Manager
 * @author                AutomatorWP
 * @copyright             Copyright (c) AutomatorWP
 */

final class AutomatorWP_WP_Job_Manager {

    /**
     * @var         AutomatorWP_WP_Job_Manager $instance The one true AutomatorWP_WP_Job_Manager
     * @since       1.0.0
     */
    private static $instance;

    /**
     * Get active instance
     *
     * @access      public
     * @since       1.0.0
     * @return      AutomatorWP_WP_Job_Manager self::$instance The one true AutomatorWP_WP_Job_Manager
     */
    public static function instance() {
        if( !self::$instance ) {
            self::$instance = new AutomatorWP_WP_Job_Manager();
            self::$instance->constants();
            self::$instance->includes();
            self::$instance->hooks();
            self::$instance->load_textdomain();
        }

        return self::$instance;
    }

    /**
     * Setup plugin constants
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function constants() {
        // Plugin version
        define( 'AUTOMATORWP_WP_JOB_MANAGER_VER', '1.0.2' );

        // Plugin file
        define( 'AUTOMATORWP_WP_JOB_MANAGER_FILE', __FILE__ );

        // Plugin path
        define( 'AUTOMATORWP_WP_JOB_MANAGER_DIR', plugin_dir_path( __FILE__ ) );

        // Plugin URL
        define( 'AUTOMATORWP_WP_JOB_MANAGER_URL', plugin_dir_url( __FILE__ ) );
    }

    /**
     * Include plugin files
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function includes() {

        if( $this->meets_requirements() ) {

            // Triggers
            require_once AUTOMATORWP_WP_JOB_MANAGER_DIR . 'includes/triggers/publish-job.php';
            require_once AUTOMATORWP_WP_JOB_MANAGER_DIR . 'includes/triggers/job-filled.php';
            require_once AUTOMATORWP_WP_JOB_MANAGER_DIR . 'includes/triggers/job-not-filled.php';
            // Applications
            require_once AUTOMATORWP_WP_JOB_MANAGER_DIR . 'includes/triggers/apply-job.php';
            require_once AUTOMATORWP_WP_JOB_MANAGER_DIR . 'includes/triggers/get-application.php';
            require_once AUTOMATORWP_WP_JOB_MANAGER_DIR . 'includes/triggers/application-status.php';

        }
    }

    /**
     * Setup plugin hooks
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function hooks() {

        add_action( 'automatorwp_init', array( $this, 'register_integration' ) );

        add_filter( 'automatorwp_licenses_meta_boxes', array( $this, 'license' ) );

        // Setup our activation and deactivation hooks
        register_activation_hook( __FILE__, array( $this, 'activate' ) );
        register_deactivation_hook( __FILE__, array( $this, 'deactivate' ) );

        add_action( 'admin_notices', array( $this, 'admin_notices' ) );
    }

    /**
     * Registers this integration
     *
     * @since 1.0.0
     */
    function register_integration() {

        automatorwp_register_integration( 'wp_job_manager', array(
            'label' => 'WP Job Manager',
            'icon'  => AUTOMATORWP_WP_JOB_MANAGER_URL . 'assets/wp-job-manager.svg',
        ) );

    }

    /**
     * Licensing
     *
     * @since 1.0.0
     *
     * @param array $meta_boxes
     *
     * @return array
     */
    function license( $meta_boxes ) {

        $meta_boxes['automatorwp-wp-job-manager-license'] = array(
            'title' => 'WP Job Manager',
            'fields' => array(
                'automatorwp_wp_job_manager_license' => array(
                    'type' => 'edd_license',
                    'file' => AUTOMATORWP_WP_JOB_MANAGER_FILE,
                    'item_name' => 'WP Job Manager',
                ),
            )
        );

        return $meta_boxes;

    }

    /**
     * Activation hook for the plugin.
     *
     * @since  1.0.0
     */
    function activate() {

        if( $this->meets_requirements() ) {

        }

    }

    /**
     * Deactivation hook for the plugin.
     *
     * @since  1.0.0
     */
    function deactivate() {

    }

    /**
     * Plugin admin notices.
     *
     * @since  1.0.0
     */
    public function admin_notices() {

        if ( ! $this->meets_requirements() && ! defined( 'AUTOMATORWP_ADMIN_NOTICES' ) ) : ?>

            <div id="message" class="notice notice-error is-dismissible">
                <p>
                    <?php printf(
                        __( 'AutomatorWP - WP Job Manager requires %s and %s in order to work. Please install and activate them.', 'automatorwp-wp-job-manager' ),
                        '<a href="https://wordpress.org/plugins/automatorwp/" target="_blank">AutomatorWP</a>',
                        '<a href="https://wordpress.org/plugins/wp-job-manager/" target="_blank">WP Job Manager</a>'
                    ); ?>
                </p>
            </div>

            <?php define( 'AUTOMATORWP_ADMIN_NOTICES', true ); ?>

        <?php endif;

    }

    /**
     * Check if there are all plugin requirements
     *
     * @since  1.0.0
     *
     * @return bool True if installation meets all requirements
     */
    private function meets_requirements() {

        if ( ! class_exists( 'AutomatorWP' ) ) {
            return false;
        }

        if ( ! class_exists( 'WP_Job_Manager' ) ) {
            return false;
        }

        return true;

    }

    /**
     * Internationalization
     *
     * @access      public
     * @since       1.0.0
     * @return      void
     */
    public function load_textdomain() {

        // Set filter for language directory
        $lang_dir = AUTOMATORWP_WP_JOB_MANAGER_DIR . '/languages/';
        $lang_dir = apply_filters( 'automatorwp_wp_job_manager_languages_directory', $lang_dir );

        // Traditional WordPress plugin locale filter
        $locale = apply_filters( 'plugin_locale', get_locale(), 'automatorwp-wp-job-manager' );
        $mofile = sprintf( '%1$s-%2$s.mo', 'automatorwp-wp-job-manager', $locale );

        // Setup paths to current locale file
        $mofile_local   = $lang_dir . $mofile;
        $mofile_global  = WP_LANG_DIR . '/automatorwp-wp-job-manager/' . $mofile;

        if( file_exists( $mofile_global ) ) {
            // Look in global /wp-content/languages/automatorwp-wp-job-manager/ folder
            load_textdomain( 'automatorwp-wp-job-manager', $mofile_global );
        } elseif( file_exists( $mofile_local ) ) {
            // Look in local /wp-content/plugins/automatorwp-wp-job-manager/languages/ folder
            load_textdomain( 'automatorwp-wp-job-manager', $mofile_local );
        } else {
            // Load the default language files
            load_plugin_textdomain( 'automatorwp-wp-job-manager', false, $lang_dir );
        }

    }

}

/**
 * The main function responsible for returning the one true AutomatorWP_WP_Job_Manager instance to functions everywhere
 *
 * @since       1.0.0
 * @return      \AutomatorWP_WP_Job_Manager The one true AutomatorWP_WP_Job_Manager
 */
function AutomatorWP_WP_Job_Manager() {
    return AutomatorWP_WP_Job_Manager::instance();
}
add_action( 'plugins_loaded', 'AutomatorWP_WP_Job_Manager' );
