<?php
/**
 * Plugin Name:           AutomatorWP - WP Simple Pay
 * Plugin URI:            https://automatorwp.com/add-ons/wp-simple-pay/
 * Description:           Connect AutomatorWP with WP Simple Pay.
 * Version:               1.0.0
 * Author:                AutomatorWP
 * Author URI:            https://automatorwp.com/
 * Text Domain:           automatorwp-wp-simple-pay
 * Domain Path:           /languages/
 * Requires at least:     4.4
 * Tested up to:          5.4
 * License:               GNU AGPL v3.0 (http://www.gnu.org/licenses/agpl.txt)
 *
 * @package               AutomatorWP\WP_Simple_Pay
 * @author                AutomatorWP
 * @copyright             Copyright (c) AutomatorWP
 */

final class AutomatorWP_WP_Simple_Pay {

    /**
     * @var         AutomatorWP_WP_Simple_Pay $instance The one true AutomatorWP_WP_Simple_Pay
     * @since       1.0.0
     */
    private static $instance;

    /**
     * Get active instance
     *
     * @access      public
     * @since       1.0.0
     * @return      AutomatorWP_WP_Simple_Pay self::$instance The one true AutomatorWP_WP_Simple_Pay
     */
    public static function instance() {
        if( !self::$instance ) {
            self::$instance = new AutomatorWP_WP_Simple_Pay();
            self::$instance->constants();
            self::$instance->includes();
            self::$instance->hooks();
            self::$instance->load_textdomain();
        }

        return self::$instance;
    }

    /**
     * Setup plugin constants
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function constants() {
        // Plugin version
        define( 'AUTOMATORWP_WP_SIMPLE_PAY_VER', '1.0.0' );

        // Plugin file
        define( 'AUTOMATORWP_WP_SIMPLE_PAY_FILE', __FILE__ );

        // Plugin path
        define( 'AUTOMATORWP_WP_SIMPLE_PAY_DIR', plugin_dir_path( __FILE__ ) );

        // Plugin URL
        define( 'AUTOMATORWP_WP_SIMPLE_PAY_URL', plugin_dir_url( __FILE__ ) );
    }

    /**
     * Include plugin files
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function includes() {

        if( $this->meets_requirements() ) {

            if( SIMPLE_PAY_PLUGIN_NAME === 'WP Simple Pay Pro' ) {

                // Triggers
                require_once AUTOMATORWP_WP_SIMPLE_PAY_DIR . 'includes/triggers/complete-purchase.php';
                require_once AUTOMATORWP_WP_SIMPLE_PAY_DIR . 'includes/triggers/renew-subscription.php';

            } else {

                // Lite Triggers
                require_once AUTOMATORWP_WP_SIMPLE_PAY_DIR . 'includes/triggers/complete-purchase-lite.php';

            }

        }
    }

    /**
     * Setup plugin hooks
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function hooks() {

        add_action( 'automatorwp_init', array( $this, 'register_integration' ) );

        add_filter( 'automatorwp_licenses_meta_boxes', array( $this, 'license' ) );

        add_action( 'admin_notices', array( $this, 'admin_notices' ) );
    }

    /**
     * Registers this integration
     *
     * @since 1.0.0
     */
    function register_integration() {

        automatorwp_register_integration( 'wp_simple_pay', array(
            'label' => 'WP Simple Pay',
            'icon'  => AUTOMATORWP_WP_SIMPLE_PAY_URL . 'assets/wp-simple-pay.svg',
        ) );

    }

    /**
     * Licensing
     *
     * @since 1.0.0
     *
     * @param array $meta_boxes
     *
     * @return array
     */
    function license( $meta_boxes ) {

        $meta_boxes['automatorwp-wp-simple-pay-license'] = array(
            'title' => 'WP Simple Pay',
            'fields' => array(
                'automatorwp_wp_simple_pay_license' => array(
                    'type' => 'edd_license',
                    'file' => AUTOMATORWP_WP_SIMPLE_PAY_FILE,
                    'item_name' => 'WP Simple Pay',
                ),
            )
        );

        return $meta_boxes;

    }

    /**
     * Plugin admin notices.
     *
     * @since  1.0.0
     */
    public function admin_notices() {

        if ( ! $this->meets_requirements() && ! defined( 'AUTOMATORWP_ADMIN_NOTICES' ) ) : ?>

            <div id="message" class="notice notice-error is-dismissible">
                <p>
                    <?php printf(
                        __( 'AutomatorWP - WP Simple Pay requires %s and %s in order to work. Please install and activate them.', 'automatorwp-wp-simple-pay' ),
                        '<a href="https://wordpress.org/plugins/automatorwp/" target="_blank">AutomatorWP</a>',
                        '<a href="https://wordpress.org/plugins/stripe/" target="_blank">WP Simple Pay</a>'
                    ); ?>
                </p>
            </div>

            <?php define( 'AUTOMATORWP_ADMIN_NOTICES', true ); ?>

        <?php endif;

    }

    /**
     * Check if there are all plugin requirements
     *
     * @since  1.0.0
     *
     * @return bool True if installation meets all requirements
     */
    private function meets_requirements() {

        if ( ! class_exists( 'AutomatorWP' ) ) {
            return false;
        }

        if ( ! defined( 'SIMPLE_PAY_PLUGIN_NAME' ) ) {
            return false;
        }

        return true;

    }

    /**
     * Internationalization
     *
     * @access      public
     * @since       1.0.0
     * @return      void
     */
    public function load_textdomain() {

        // Set filter for language directory
        $lang_dir = AUTOMATORWP_WP_SIMPLE_PAY_DIR . '/languages/';
        $lang_dir = apply_filters( 'automatorwp_wp_simple_pay_languages_directory', $lang_dir );

        // Traditional WordPress plugin locale filter
        $locale = apply_filters( 'plugin_locale', get_locale(), 'automatorwp-wp-simple-pay' );
        $mofile = sprintf( '%1$s-%2$s.mo', 'automatorwp-wp-simple-pay', $locale );

        // Setup paths to current locale file
        $mofile_local   = $lang_dir . $mofile;
        $mofile_global  = WP_LANG_DIR . '/automatorwp-wp-simple-pay/' . $mofile;

        if( file_exists( $mofile_global ) ) {
            // Look in global /wp-content/languages/automatorwp-wp-simple-pay/ folder
            load_textdomain( 'automatorwp-wp-simple-pay', $mofile_global );
        } elseif( file_exists( $mofile_local ) ) {
            // Look in local /wp-content/plugins/automatorwp-wp-simple-pay/languages/ folder
            load_textdomain( 'automatorwp-wp-simple-pay', $mofile_local );
        } else {
            // Load the default language files
            load_plugin_textdomain( 'automatorwp-wp-simple-pay', false, $lang_dir );
        }

    }

}

/**
 * The main function responsible for returning the one true AutomatorWP_WP_Simple_Pay instance to functions everywhere
 *
 * @since       1.0.0
 * @return      \AutomatorWP_WP_Simple_Pay The one true AutomatorWP_WP_Simple_Pay
 */
function AutomatorWP_WP_Simple_Pay() {
    return AutomatorWP_WP_Simple_Pay::instance();
}
add_action( 'plugins_loaded', 'AutomatorWP_WP_Simple_Pay' );
