<?php
/**
 * Join Group Rejected
 *
 * @package     AutomatorWP\Integrations\WP_User_Manager\Triggers\Join_Group_Rejected
 * @author      AutomatorWP <contact@automatorwp.com>, Ruben Garcia <rubengcdev@gmail.com>
 * @since       1.0.0
 */
// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

class AutomatorWP_WP_User_Manager_Join_Group_Rejected extends AutomatorWP_Integration_Trigger {

    public $integration = 'wp_user_manager';
    public $trigger = 'wp_user_manager_join_group_rejected';

    /**
     * Register the trigger
     *
     * @since 1.0.0
     */
    public function register() {

        automatorwp_register_trigger( $this->trigger, array(
            'integration'       => $this->integration,
            'label'             => __( 'User gets rejected in a private group', 'automatorwp-wp-user-manager' ),
            'select_option'     => __( 'User gets <strong>rejected</strong> in a private group', 'automatorwp-wp-user-manager' ),
            /* translators: %1$s: Group. %2$s: Number of times. */
            'edit_label'        => sprintf( __( 'User gets rejected in %1$s %2$s time(s)', 'automatorwp-wp-user-manager' ), '{post}', '{times}' ),
            /* translators: %1$s: Group. */
            'log_label'         => sprintf( __( 'User gets rejected in %1$s', 'automatorwp-wp-user-manager' ), '{post}' ),
            'action'            => 'wpumgp_after_membership_rejected',
            'function'          => array( $this, 'listener' ),
            'priority'          => 10,
            'accepted_args'     => 2,
            'options'           => array(
                'post' => automatorwp_utilities_post_option( array(
                    'name' => __( 'Group:', 'automatorwp-wp-user-manager' ),
                    'option_none_label' => __( 'any group', 'automatorwp-wp-user-manager' ),
                    'post_type' => 'wpum_group'
                ) ),
                'times' => automatorwp_utilities_times_option(),
            ),
            'tags' => array(
                'times' => automatorwp_utilities_times_tag( true )
            )
        ) );

    }

    /**
     * Trigger listener
     *
     * @since 1.0.0
     *
     * @param int $group_id
     * @param int $user_id
     */
    public function listener( $group_id, $user_id ) {

        automatorwp_trigger_event( array(
            'trigger'       => $this->trigger,
            'user_id'       => $user_id,
            'group_id'      => $group_id,
        ) );

    }

    /**
     * User deserves check
     *
     * @since 1.0.0
     *
     * @param bool      $deserves_trigger   True if user deserves trigger, false otherwise
     * @param stdClass  $trigger            The trigger object
     * @param int       $user_id            The user ID
     * @param array     $event              Event information
     * @param array     $trigger_options    The trigger's stored options
     * @param stdClass  $automation         The trigger's automation object
     *
     * @return bool                          True if user deserves trigger, false otherwise
     */
    public function user_deserves_trigger( $deserves_trigger, $trigger, $user_id, $event, $trigger_options, $automation ) {

        // Don't deserve if post is not received
        if( ! isset( $event['group_id'] ) ) {
            return false;
        }

        // Bail if group doesn't match with the trigger option
        if( $trigger_options['group'] !== 'any' && absint( $event['group_id'] ) !== absint( $trigger_options['group'] ) ) {
            return false;
        }

        return $deserves_trigger;

    }

}

new AutomatorWP_WP_User_Manager_Join_Group_Rejected();