<?php
/**
 * Plugin Name:           AutomatorWP - WPForms
 * Plugin URI:            https://automatorwp.com/add-ons/wpforms/
 * Description:           Connect AutomatorWP with WPForms.
 * Version:               1.0.4
 * Author:                AutomatorWP
 * Author URI:            https://automatorwp.com/
 * Text Domain:           automatorwp-wpforms
 * Domain Path:           /languages/
 * Requires at least:     4.4
 * Tested up to:          5.4
 * License:               GNU AGPL v3.0 (http://www.gnu.org/licenses/agpl.txt)
 *
 * @package               AutomatorWP\WPForms
 * @author                AutomatorWP
 * @copyright             Copyright (c) AutomatorWP
 */

final class AutomatorWP_WPForms {

    /**
     * @var         AutomatorWP_WPForms $instance The one true AutomatorWP_WPForms
     * @since       1.0.0
     */
    private static $instance;

    /**
     * Get active instance
     *
     * @access      public
     * @since       1.0.0
     * @return      AutomatorWP_WPForms self::$instance The one true AutomatorWP_WPForms
     */
    public static function instance() {
        if( !self::$instance ) {
            self::$instance = new AutomatorWP_WPForms();
            self::$instance->constants();
            self::$instance->includes();
            self::$instance->hooks();
            self::$instance->load_textdomain();
        }

        return self::$instance;
    }

    /**
     * Setup plugin constants
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function constants() {
        // Plugin version
        define( 'AUTOMATORWP_WPFORMS_VER', '1.0.4' );

        // Plugin file
        define( 'AUTOMATORWP_WPFORMS_FILE', __FILE__ );

        // Plugin path
        define( 'AUTOMATORWP_WPFORMS_DIR', plugin_dir_path( __FILE__ ) );

        // Plugin URL
        define( 'AUTOMATORWP_WPFORMS_URL', plugin_dir_url( __FILE__ ) );
    }

    /**
     * Include plugin files
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function includes() {

        if( $this->meets_requirements() ) {

            // Triggers
            require_once AUTOMATORWP_WPFORMS_DIR . 'includes/triggers/submit-form.php';
            require_once AUTOMATORWP_WPFORMS_DIR . 'includes/triggers/submit-field-value.php';
            // Anonymous Triggers
            require_once AUTOMATORWP_WPFORMS_DIR . 'includes/triggers/anonymous-submit-form.php';
            require_once AUTOMATORWP_WPFORMS_DIR . 'includes/triggers/anonymous-submit-field-value.php';

            // Includes
            require_once AUTOMATORWP_WPFORMS_DIR . 'includes/functions.php';

        }
    }

    /**
     * Setup plugin hooks
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function hooks() {

        add_action( 'automatorwp_init', array( $this, 'register_integration' ) );

        add_filter( 'automatorwp_licenses_meta_boxes', array( $this, 'license' ) );

        add_action( 'admin_notices', array( $this, 'admin_notices' ) );
    }

    /**
     * Registers this integration
     *
     * @since 1.0.0
     */
    function register_integration() {

        automatorwp_register_integration( 'wpforms', array(
            'label' => 'WPForms',
            'icon'  => AUTOMATORWP_WPFORMS_URL . 'assets/wpforms.svg',
        ) );

    }

    /**
     * Licensing
     *
     * @since 1.0.0
     *
     * @param array $meta_boxes
     *
     * @return array
     */
    function license( $meta_boxes ) {

        $meta_boxes['automatorwp-wpforms-license'] = array(
            'title' => 'WPForms',
            'fields' => array(
                'automatorwp_wpforms_license' => array(
                    'type' => 'edd_license',
                    'file' => AUTOMATORWP_WPFORMS_FILE,
                    'item_name' => 'WPForms',
                ),
            )
        );

        return $meta_boxes;

    }

    /**
     * Plugin admin notices.
     *
     * @since  1.0.0
     */
    public function admin_notices() {

        if ( ! $this->meets_requirements() && ! defined( 'AUTOMATORWP_ADMIN_NOTICES' ) ) : ?>

            <div id="message" class="notice notice-error is-dismissible">
                <p>
                    <?php printf(
                        __( 'AutomatorWP - WPForms requires %s and %s in order to work. Please install and activate them.', 'automatorwp-wpforms' ),
                        '<a href="https://wordpress.org/plugins/automatorwp/" target="_blank">AutomatorWP</a>',
                        '<a href="https://wordpress.org/plugins/wpforms-lite/" target="_blank">WPForms</a>'
                    ); ?>
                </p>
            </div>

            <?php define( 'AUTOMATORWP_ADMIN_NOTICES', true ); ?>

        <?php endif;

    }

    /**
     * Check if there are all plugin requirements
     *
     * @since  1.0.0
     *
     * @return bool True if installation meets all requirements
     */
    private function meets_requirements() {

        if ( ! class_exists( 'AutomatorWP' ) ) {
            return false;
        }

        if ( ! function_exists( 'wpforms' ) ) {
            return false;
        }

        return true;

    }

    /**
     * Internationalization
     *
     * @access      public
     * @since       1.0.0
     * @return      void
     */
    public function load_textdomain() {

        // Set filter for language directory
        $lang_dir = AUTOMATORWP_WPFORMS_DIR . '/languages/';
        $lang_dir = apply_filters( 'automatorwp_wpforms_languages_directory', $lang_dir );

        // Traditional WordPress plugin locale filter
        $locale = apply_filters( 'plugin_locale', get_locale(), 'automatorwp-wpforms' );
        $mofile = sprintf( '%1$s-%2$s.mo', 'automatorwp-wpforms', $locale );

        // Setup paths to current locale file
        $mofile_local   = $lang_dir . $mofile;
        $mofile_global  = WP_LANG_DIR . '/automatorwp-wpforms/' . $mofile;

        if( file_exists( $mofile_global ) ) {
            // Look in global /wp-content/languages/automatorwp-wpforms/ folder
            load_textdomain( 'automatorwp-wpforms', $mofile_global );
        } elseif( file_exists( $mofile_local ) ) {
            // Look in local /wp-content/plugins/automatorwp-wpforms/languages/ folder
            load_textdomain( 'automatorwp-wpforms', $mofile_local );
        } else {
            // Load the default language files
            load_plugin_textdomain( 'automatorwp-wpforms', false, $lang_dir );
        }

    }

}

/**
 * The main function responsible for returning the one true AutomatorWP_WPForms instance to functions everywhere
 *
 * @since       1.0.0
 * @return      \AutomatorWP_WPForms The one true AutomatorWP_WPForms
 */
function AutomatorWP_WPForms() {
    return AutomatorWP_WPForms::instance();
}
add_action( 'plugins_loaded', 'AutomatorWP_WPForms' );
