<?php
/**
 * Subscribe Course
 *
 * @package     AutomatorWP\Integrations\WPLMS\Triggers\Subscribe_Course
 * @author      AutomatorWP <contact@automatorwp.com>, Ruben Garcia <rubengcdev@gmail.com>
 * @since       1.0.0
 */
// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

class AutomatorWP_WPLMS_Subscribe_Course extends AutomatorWP_Integration_Trigger {

    public $integration = 'wplms';
    public $trigger = 'wplms_subscribe_course';

    /**
     * Register the trigger
     *
     * @since 1.0.0
     */
    public function register() {

        automatorwp_register_trigger( $this->trigger, array(
            'integration'       => $this->integration,
            'label'             => __( 'User subscribes or unsubscribes in a course', 'automatorwp-wplms' ),
            'select_option'     => __( 'User <strong>subscribes or unsubscribes</strong> a course', 'automatorwp-wplms' ),
            /* translators: %1$s: Operation (subscribes or unsubscribes). %2$s: Post title. %3$s: Number of times. */
            'edit_label'        => sprintf( __( 'User %1$s %2$s %3$s time(s)', 'automatorwp-wplms' ), '{operation}', '{post}', '{times}' ),
            /* translators: %1$s: Operation (subscribes or unsubscribes). %2$s: Post title. */
            'log_label'         => sprintf( __( 'User %1$s %2$s', 'automatorwp-wplms' ), '{operation}', '{post}' ),
            'action'            => array(
                'wplms_course_subscribed',
                'wplms_course_unsubscribe',
            ),
            'function'          => array( $this, 'listener' ),
            'priority'          => 10,
            'accepted_args'     => 2,
            'options'           => array(
                'operation' => array(
                    'from' => 'operation',
                    'fields' => array(
                        'operation' => array(
                            'name' => __( 'Operation:', 'automatorwp-wplms' ),
                            'type' => 'select',
                            'options' => array(
                                'subscribe'     => __( 'subscribes', 'automatorwp-wplms' ),
                                'unsubscribe'   => __( 'unsubscribes', 'automatorwp-wplms' ),
                            ),
                            'default' => 'subscribe'
                        ),
                    )
                ),
                'post' => automatorwp_utilities_post_option( array(
                    'name' => __( 'Course:', 'automatorwp-wplms' ),
                    'option_none_label' => __( 'any course', 'automatorwp-wplms' ),
                    'post_type' => 'course'
                ) ),
                'times' => automatorwp_utilities_times_option(),
            ),
            'tags' => array_merge(
                automatorwp_utilities_post_tags(),
                automatorwp_utilities_times_tag()
            )
        ) );

    }

    /**
     * Trigger listener
     *
     * @since 1.0.0
     *
     * @param integer $course_id
     * @param integer $user_id
     */
    public function listener( $course_id, $user_id ) {

        $operation = '';

        switch ( current_filter() ) {
            case 'wplms_course_subscribed':
                $operation = 'subscribe';
                break;
            case 'wplms_course_unsubscribe':
                $operation = 'unsubscribe';
                break;
        }

        automatorwp_trigger_event( array(
            'trigger'   => $this->trigger,
            'user_id'   => $user_id,
            'post_id'   => $course_id,
            'operation' => $operation,
        ) );

    }

    /**
     * User deserves check
     *
     * @since 1.0.0
     *
     * @param bool      $deserves_trigger   True if user deserves trigger, false otherwise
     * @param stdClass  $trigger            The trigger object
     * @param int       $user_id            The user ID
     * @param array     $event              Event information
     * @param array     $trigger_options    The trigger's stored options
     * @param stdClass  $automation         The trigger's automation object
     *
     * @return bool                          True if user deserves trigger, false otherwise
     */
    public function user_deserves_trigger( $deserves_trigger, $trigger, $user_id, $event, $trigger_options, $automation ) {

        // Shorthand
        $operation = $trigger_options['operation'];

        // Ensure operation default value
        if( empty( $operation ) ) {
            $operation = 'subscribe';
        }

        // Don't deserve if post is not received
        if( ! isset( $event['post_id'] ) && ! isset( $event['operation'] ) ) {
            return false;
        }

        // Don't deserve if post doesn't match with the trigger option
        if( ! automatorwp_posts_matches( $event['post_id'], $trigger_options['post'] ) ) {
            return false;
        }

        // Don't deserve if operation doesn't match with the trigger option
        if( $operation !== $event['operation'] ) {
            return false;
        }

        return $deserves_trigger;

    }

}

new AutomatorWP_WPLMS_Subscribe_Course();