<?php
/**
 * Plugin Name:           AutomatorWP - WS Form
 * Plugin URI:            https://automatorwp.com/add-ons/ws-form/
 * Description:           Connect AutomatorWP with WS Form.
 * Version:               1.0.1
 * Author:                AutomatorWP
 * Author URI:            https://automatorwp.com/
 * Text Domain:           automatorwp-ws-form
 * Domain Path:           /languages/
 * Requires at least:     4.4
 * Tested up to:          5.7
 * License:               GNU AGPL v3.0 (http://www.gnu.org/licenses/agpl.txt)
 *
 * @package               AutomatorWP\WS_Form
 * @author                AutomatorWP
 * @copyright             Copyright (c) AutomatorWP
 */

final class AutomatorWP_WS_Form {

    /**
     * @var         AutomatorWP_WS_Form $instance The one true AutomatorWP_WS_Form
     * @since       1.0.0
     */
    private static $instance;

    /**
     * Get active instance
     *
     * @access      public
     * @since       1.0.0
     * @return      AutomatorWP_WS_Form self::$instance The one true AutomatorWP_WS_Form
     */
    public static function instance() {
        if( !self::$instance ) {
            self::$instance = new AutomatorWP_WS_Form();
            self::$instance->constants();
            self::$instance->includes();
            self::$instance->hooks();
            self::$instance->load_textdomain();
        }

        return self::$instance;
    }

    /**
     * Setup plugin constants
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function constants() {
        // Plugin version
        define( 'AUTOMATORWP_WS_FORM_VER', '1.0.1' );

        // Plugin file
        define( 'AUTOMATORWP_WS_FORM_FILE', __FILE__ );

        // Plugin path
        define( 'AUTOMATORWP_WS_FORM_DIR', plugin_dir_path( __FILE__ ) );

        // Plugin URL
        define( 'AUTOMATORWP_WS_FORM_URL', plugin_dir_url( __FILE__ ) );
    }

    /**
     * Include plugin files
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function includes() {

        if( $this->meets_requirements() ) {

            // Triggers
            require_once AUTOMATORWP_WS_FORM_DIR . 'includes/triggers/submit-form.php';
            require_once AUTOMATORWP_WS_FORM_DIR . 'includes/triggers/submit-field-value.php';

            // Anonymous Triggers
            require_once AUTOMATORWP_WS_FORM_DIR . 'includes/triggers/anonymous-submit-form.php';
            require_once AUTOMATORWP_WS_FORM_DIR . 'includes/triggers/anonymous-submit-field-value.php';

            // Includes
            require_once AUTOMATORWP_WS_FORM_DIR . 'includes/ajax-functions.php';
            require_once AUTOMATORWP_WS_FORM_DIR . 'includes/functions.php';

        }
    }

    /**
     * Setup plugin hooks
     *
     * @access      private
     * @since       1.0.0
     * @return      void
     */
    private function hooks() {

        add_action( 'automatorwp_init', array( $this, 'register_integration' ) );

        add_filter( 'automatorwp_licenses_meta_boxes', array( $this, 'license' ) );

        // Setup our activation and deactivation hooks
        register_activation_hook( __FILE__, array( $this, 'activate' ) );
        register_deactivation_hook( __FILE__, array( $this, 'deactivate' ) );

        add_action( 'admin_notices', array( $this, 'admin_notices' ) );
    }

    /**
     * Registers this integration
     *
     * @since 1.0.0
     */
    function register_integration() {

        automatorwp_register_integration( 'ws_form', array(
            'label' => 'WS Form',
            'icon'  => AUTOMATORWP_WS_FORM_URL . 'assets/ws-form.svg',
        ) );

    }

    /**
     * Licensing
     *
     * @since 1.0.0
     *
     * @param array $meta_boxes
     *
     * @return array
     */
    function license( $meta_boxes ) {

        $meta_boxes['automatorwp-ws-form-license'] = array(
            'title' => 'WS Form',
            'fields' => array(
                'automatorwp_ws_form_license' => array(
                    'type' => 'edd_license',
                    'file' => AUTOMATORWP_WS_FORM_FILE,
                    'item_name' => 'WS Form',
                ),
            )
        );

        return $meta_boxes;

    }

    /**
     * Activation hook for the plugin.
     *
     * @since  1.0.0
     */
    function activate() {

        if( $this->meets_requirements() ) {

        }

    }

    /**
     * Deactivation hook for the plugin.
     *
     * @since  1.0.0
     */
    function deactivate() {

    }

    /**
     * Plugin admin notices.
     *
     * @since  1.0.0
     */
    public function admin_notices() {

        if ( ! $this->meets_requirements() && ! defined( 'AUTOMATORWP_ADMIN_NOTICES' ) ) : ?>

            <div id="message" class="notice notice-error is-dismissible">
                <p>
                    <?php printf(
                        __( 'AutomatorWP - WS Form requires %s and %s in order to work. Please install and activate them.', 'automatorwp-ws-form' ),
                        '<a href="https://wordpress.org/plugins/automatorwp/" target="_blank">AutomatorWP</a>',
                        '<a href="http://wsform.com/" target="_blank">WS Form 1.8.71+</a>'
                    ); ?>
                </p>
            </div>

            <?php define( 'AUTOMATORWP_ADMIN_NOTICES', true ); ?>

        <?php endif;

    }

    /**
     * Check if there are all plugin requirements
     *
     * @since  1.0.0
     *
     * @return bool True if installation meets all requirements
     */
    private function meets_requirements() {

        if ( ! class_exists( 'AutomatorWP' ) ) {
            return false;
        }

        if ( ! class_exists( 'WS_Form' ) ) {
            return false;
        }

        if ( ! version_compare( WS_FORM_VERSION, '1.8.71' ) ) {
            return false;
        }

        return true;

    }

    /**
     * Internationalization
     *
     * @access      public
     * @since       1.0.0
     * @return      void
     */
    public function load_textdomain() {

        // Set filter for language directory
        $lang_dir = AUTOMATORWP_WS_FORM_DIR . '/languages/';
        $lang_dir = apply_filters( 'automatorwp_ws_form_languages_directory', $lang_dir );

        // Traditional WordPress plugin locale filter
        $locale = apply_filters( 'plugin_locale', get_locale(), 'automatorwp-ws-form' );
        $mofile = sprintf( '%1$s-%2$s.mo', 'automatorwp-ws-form', $locale );

        // Setup paths to current locale file
        $mofile_local   = $lang_dir . $mofile;
        $mofile_global  = WP_LANG_DIR . '/automatorwp-ws-form/' . $mofile;

        if( file_exists( $mofile_global ) ) {
            // Look in global /wp-content/languages/automatorwp-ws-form/ folder
            load_textdomain( 'automatorwp-ws-form', $mofile_global );
        } elseif( file_exists( $mofile_local ) ) {
            // Look in local /wp-content/plugins/automatorwp-ws-form/languages/ folder
            load_textdomain( 'automatorwp-ws-form', $mofile_local );
        } else {
            // Load the default language files
            load_plugin_textdomain( 'automatorwp-ws-form', false, $lang_dir );
        }

    }

}

/**
 * The main function responsible for returning the one true AutomatorWP_WS_Form instance to functions everywhere
 *
 * @since       1.0.0
 * @return      \AutomatorWP_WS_Form The one true AutomatorWP_WS_Form
 */
function AutomatorWP_WS_Form() {
    return AutomatorWP_WS_Form::instance();
}
add_action( 'plugins_loaded', 'AutomatorWP_WS_Form' );
