<?php
/**
 * Functions
 *
 * @package     AutomatorWP\Generator\Functions
 * @since       1.0.0
 */
// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

/**
 * Get the tags
 *
 * @since 1.0.0
 *
 * @return array
 */
function automatorwp_generator_random_string( $length, $allowed_characters ) {
    
    $characters = '';

    // Lowercase
    if( in_array( 'lowercase', $allowed_characters ) ) {
        $characters = $characters . 'abcdefghijklmnopqrstuvwxyz';
    }
    
    // Uppercase
    if( in_array( 'uppercase', $allowed_characters ) ) {
        $characters = $characters . 'ABCDEFGHIJKLMNOPQRSTUVWXYZ';
    }
    
    // Special characters
    if( in_array( 'special', $allowed_characters ) ) {
        $characters = $characters . '!#$%&()*+,-./:;<=>?@[\]^_`|~';
    }

    // Numbers
    if( in_array( 'number', $allowed_characters ) ) {
        $characters = $characters . '0123456789';
    }

    $random_string = substr( str_shuffle( str_repeat( $characters, ceil( $length / strlen( $characters ) ) ) ), 1, $length );

    return $random_string;
    
}

/**
 * Options callback for select2 fields assigned to algorithms
 *
 * @since 1.0.0
 *
 * @param stdClass $field
 *
 * @return array
 */
function automatorwp_generator_options_cb_algorithm( $field ) {

    // Setup vars
    $value = $field->escaped_value;
    $none_value = 'any';
    $none_label = __( 'any algorithm', 'automatorwp' );
    $options = automatorwp_options_cb_none_option( $field, $none_value, $none_label );

    if( ! empty( $value ) ) {
        if( ! is_array( $value ) ) {
            $value = array( $value );
        }

        foreach( $value as $algorithm_id ) {

            // Skip option none
            if( $algorithm_id === $none_value ) {
                continue;
            }

            $options[$algorithm_id] = automatorwp_generator_get_algorithm_title( $algorithm_id );
        }
    }

    return $options;

}

/**
 * Get the algorithm title
 *
 * @since 1.0.0
 *
 * @param int $algorithm_id
 *
 * @return string|null
 */
function automatorwp_generator_get_algorithm_title( $algorithm_id ) {

    // Empty title if no ID provided
    if( absint( $algorithm_id ) === 0 ) {
        return '';
    }

    $algorithms = hash_algos();

    return $algorithms[$algorithm_id];

}