<?php
/**
 * Tags
 *
 * @package     AutomatorWP\Generator\Tags
 * @since       1.0.0
 */
// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

/**
 * Random number tags
 *
 * @since 1.0.0
 *
 * @return array
 */
function automatorwp_generator_get_actions_random_number_tags() {

    return array(
        'random_number' => array(
            'label'     => __( 'Random number', 'automatorwp-pro' ),
            'type'      => 'integer',
            'preview'   => '123',
        ),
    );

}

/**
 * Custom action random number tag replacement
 *
 * @since 1.0.0
 *
 * @param string    $replacement    The tag replacement
 * @param string    $tag_name       The tag name (without "{}")
 * @param stdClass  $action         The action object
 * @param int       $user_id        The user ID
 * @param string    $content        The content to parse
 * @param stdClass  $log            The last action log object
 *
 * @return string
 */
function automatorwp_generator_get_action_random_number_tag_replacement( $replacement, $tag_name, $action, $user_id, $content, $log ) {


    $action_args = automatorwp_get_action( $action->type );

    // Skip if action is not from this integration
    if( $action_args['integration'] !== 'generator' ) {
        return $replacement;
    }

    switch( $tag_name ) {
        case 'random_number':
            $replacement = automatorwp_get_log_meta( $log->id, 'random_number', true );
            break;
    }

    return $replacement;

}
add_filter( 'automatorwp_get_action_tag_replacement', 'automatorwp_generator_get_action_random_number_tag_replacement', 10, 6 );

/**
 * Random string tags
 *
 * @since 1.0.0
 *
 * @return array
 */
function automatorwp_generator_get_actions_random_string_tags() {

    return array(
        'random_string' => array(
            'label'     => __( 'Random string', 'automatorwp-pro' ),
            'type'      => 'text',
            'preview'   => 'random_string',
        ),
    );

}

/**
 * Custom action random string tag replacement
 *
 * @since 1.0.0
 *
 * @param string    $replacement    The tag replacement
 * @param string    $tag_name       The tag name (without "{}")
 * @param stdClass  $action         The action object
 * @param int       $user_id        The user ID
 * @param string    $content        The content to parse
 * @param stdClass  $log            The last action log object
 *
 * @return string
 */
function automatorwp_generator_get_action_random_string_tag_replacement( $replacement, $tag_name, $action, $user_id, $content, $log ) {


    $action_args = automatorwp_get_action( $action->type );

    // Skip if action is not from this integration
    if( $action_args['integration'] !== 'generator' ) {
        return $replacement;
    }

    switch( $tag_name ) {
        case 'random_string':
            $replacement = automatorwp_get_log_meta( $log->id, 'random_string', true );
            break;
    }

    return $replacement;

}
add_filter( 'automatorwp_get_action_tag_replacement', 'automatorwp_generator_get_action_random_string_tag_replacement', 10, 6 );

/**
 * Random email tags
 *
 * @since 1.0.0
 *
 * @return array
 */
function automatorwp_generator_get_actions_random_email_tags() {

    return array(
        'random_email' => array(
            'label'     => __( 'Random email', 'automatorwp-pro' ),
            'type'      => 'text',
            'preview'   => 'contact@automatorwp.com',
        ),
    );

}

/**
 * Custom action random email tag replacement
 *
 * @since 1.0.0
 *
 * @param string    $replacement    The tag replacement
 * @param string    $tag_name       The tag name (without "{}")
 * @param stdClass  $action         The action object
 * @param int       $user_id        The user ID
 * @param string    $content        The content to parse
 * @param stdClass  $log            The last action log object
 *
 * @return string
 */
function automatorwp_generator_get_action_random_email_tag_replacement( $replacement, $tag_name, $action, $user_id, $content, $log ) {


    $action_args = automatorwp_get_action( $action->type );

    // Skip if action is not from this integration
    if( $action_args['integration'] !== 'generator' ) {
        return $replacement;
    }

    switch( $tag_name ) {
        case 'random_email':
            $replacement = automatorwp_get_log_meta( $log->id, 'random_email', true );
            break;
    }

    return $replacement;

}
add_filter( 'automatorwp_get_action_tag_replacement', 'automatorwp_generator_get_action_random_email_tag_replacement', 10, 6 );

/**
 * Random hash tags
 *
 * @since 1.0.0
 *
 * @return array
 */
function automatorwp_generator_get_actions_random_hash_tags() {

    return array(
        'random_hash' => array(
            'label'     => __( 'Random hash', 'automatorwp-pro' ),
            'type'      => 'text',
            'preview'   => 'random_hash',
        ),
    );

}

/**
 * Custom action random hash tag replacement
 *
 * @since 1.0.0
 *
 * @param string    $replacement    The tag replacement
 * @param string    $tag_name       The tag name (without "{}")
 * @param stdClass  $action         The action object
 * @param int       $user_id        The user ID
 * @param string    $content        The content to parse
 * @param stdClass  $log            The last action log object
 *
 * @return string
 */
function automatorwp_generator_get_action_random_hash_tag_replacement( $replacement, $tag_name, $action, $user_id, $content, $log ) {


    $action_args = automatorwp_get_action( $action->type );

    // Skip if action is not from this integration
    if( $action_args['integration'] !== 'generator' ) {
        return $replacement;
    }

    switch( $tag_name ) {
        case 'random_hash':
            $replacement = automatorwp_get_log_meta( $log->id, 'random_hash', true );
            break;
    }

    return $replacement;

}
add_filter( 'automatorwp_get_action_tag_replacement', 'automatorwp_generator_get_action_random_hash_tag_replacement', 10, 6 );

/**
 * Random nonce tags
 *
 * @since 1.0.0
 *
 * @return array
 */
function automatorwp_generator_get_actions_random_nonce_tags() {

    return array(
        'random_nonce' => array(
            'label'     => __( 'Random nonce', 'automatorwp-pro' ),
            'type'      => 'text',
            'preview'   => 'random_nonce',
        ),
    );

}

/**
 * Custom action random nonce tag replacement
 *
 * @since 1.0.0
 *
 * @param string    $replacement    The tag replacement
 * @param string    $tag_name       The tag name (without "{}")
 * @param stdClass  $action         The action object
 * @param int       $user_id        The user ID
 * @param string    $content        The content to parse
 * @param stdClass  $log            The last action log object
 *
 * @return string
 */
function automatorwp_generator_get_action_random_nonce_tag_replacement( $replacement, $tag_name, $action, $user_id, $content, $log ) {


    $action_args = automatorwp_get_action( $action->type );

    // Skip if action is not from this integration
    if( $action_args['integration'] !== 'generator' ) {
        return $replacement;
    }

    switch( $tag_name ) {
        case 'random_nonce':
            $replacement = automatorwp_get_log_meta( $log->id, 'random_nonce', true );
            break;
    }

    return $replacement;

}
add_filter( 'automatorwp_get_action_tag_replacement', 'automatorwp_generator_get_action_random_nonce_tag_replacement', 10, 6 );